<?php
namespace Academy;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Admin {

	public static function init() {
		$self = new self();
		Admin\Menu::init();
		Admin\User::init();
		Admin\Course::init();
		Admin\Registration::init();
		Admin\Media::init();
		$self->dispatch_hooks();
		$self->add_academy_tracker();
	}
	public function dispatch_hooks() {
		// Add a post display state for special Academy pages.
		add_filter( 'display_post_states', array( $this, 'add_display_post_states' ), 10, 2 );
		add_action( 'admin_init', array( $this, 'flush_rewrite_rules' ) );
		add_action( 'transition_post_status', array( $this, 'regenerate_academy_settings_data' ), 90, 3 );
	}

	/**
	 * Add a post display state for special WC pages in the page list table.
	 *
	 * @param array   $post_states An array of post display states.
	 * @param WP_Post $post        The current post object.
	 */
	public function add_display_post_states( $post_states, $post ) {
		if ( (int) \Academy\Helper::get_settings( 'frontend_dashboard_page' ) === $post->ID ) {
			$post_states['academy_page_for_frontend_dashboard'] = __( 'Academy Frontend Dashboard Page', 'academy' );
		}
		if ( (int) \Academy\Helper::get_settings( 'course_page' ) === $post->ID ) {
			$post_states['academy_page_for_course'] = __( 'Academy Course Page', 'academy' );
		}
		if ( (int) \Academy\Helper::get_settings( 'frontend_instructor_reg_page' ) === $post->ID ) {
			$post_states['academy_instructor_registration_form'] = __( 'Academy Instructor Registration Page', 'academy' );
		}
		if ( (int) \Academy\Helper::get_settings( 'frontend_student_reg_page' ) === $post->ID ) {
			$post_states['academy_student_registration_form'] = __( 'Academy Student Registration Page', 'academy' );
		}
		return $post_states;
	}

	public function flush_rewrite_rules() {
		if ( get_option( 'academy_required_rewrite_flush' ) ) {
			delete_option( 'academy_required_rewrite_flush' );
			flush_rewrite_rules();
		}
	}
	public function regenerate_academy_settings_data( $new_status, $old_status, $post ) {
		if ( 'page' === $post->post_type && 'auto-draft' === $new_status ) {
			Cache::clear_all_cache();
		}
	}

	public function add_academy_tracker() {
		$wisdom = new Admin\AlmsDev\PluginUsageTracker(
			ACADEMY_PLUGIN_FILE,
			'https://academylms.net/',
			array(),
			true,
			true,
			1
		);
	}
}
