<?php
namespace Academy\Admin;

use Academy;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Ajax {

	public static function init() {
		$self = new self();
		add_action( 'wp_ajax_academy/admin/get_analytics', array( $self, 'get_analytics' ) );
		add_action( 'wp_ajax_academy/admin/get_enrolled_students', array( $self, 'get_enrolled_students' ) );
		add_action( 'wp_ajax_academy/admin/get_all_students', array( $self, 'get_all_students' ) );
		// instructor related ajax.
		add_action( 'wp_ajax_academy/admin/get_instructors_by_course_id', array( $self, 'get_instructors_by_course_id' ) );
		add_action( 'wp_ajax_academy/admin/get_all_instructors', array( $self, 'get_all_instructors' ) );
		add_action( 'wp_ajax_academy/admin/get_active_instructors', array( $self, 'get_active_instructors' ) );
		add_action( 'wp_ajax_academy/admin/update_instructor_status', array( $self, 'update_instructor_status' ) );
		add_action( 'wp_ajax_academy/admin/get_course_ids_by_instructor_id', array( $self, 'get_course_ids_by_instructor_id' ) );
		add_action( 'wp_ajax_academy/admin/remove_instructor_from_course', array( $self, 'remove_instructor_from_course' ) );
		// withdraw related ajax.
		add_action( 'wp_ajax_academy/admin/get_all_withdraw_request', array( $self, 'get_all_withdraw_request' ) );
		add_action( 'wp_ajax_academy/admin/update_withdraw_status', array( $self, 'update_withdraw_status' ) );
		// course slug
		add_action( 'wp_ajax_academy/admin/get_course_slug', array( $self, 'get_course_slug' ) );
	}

	public function get_analytics() {
		check_admin_referer( 'academy_nonce', 'security' );
		$analytics = new \Academy\Classes\Analytics();
		wp_send_json_success( $analytics->get_analytics() );
		wp_die();
	}

	public function get_enrolled_students() {
		check_admin_referer( 'academy_nonce', 'security' );
		$total_enrolled_students = \Academy\Helper::get_total_number_of_students();
		wp_send_json_success( array( 'total_enrolled_students' => $total_enrolled_students ) );
		wp_die();
	}

	public function get_all_instructors() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}
		$instructors = \Academy\Helper::get_all_instructors();
		$results     = \Academy\Helper::prepare_all_instructors_response( $instructors );
		wp_send_json_success( $results );
		wp_die();
	}
	public function get_active_instructors() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}
		$instructors = \Academy\Helper::get_all_approved_instructors();
		$results     = \Academy\Helper::prepare_all_instructors_response( $instructors );
		wp_send_json_success( $results );
		wp_die();
	}
	public function update_instructor_status() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}
		$ID     = ( isset( $_POST['ID'] ) ? intval( sanitize_text_field( $_POST['ID'] ) ) : '' );
		$status = ( isset( $_POST['status'] ) ? $_POST['status'] : '' );
		if ( 'approved' === $status ) {
			\Academy\Helper::set_instructor_role( $ID );
		} elseif ( 'pending' === $status ) {
			\Academy\Helper::pending_instructor_role( $ID );
		} elseif ( 'remove' === $status ) {
			\Academy\Helper::remove_instructor_role( $ID );
		}

		$instructors = \Academy\Helper::get_all_instructors();
		$results = \Academy\Helper::prepare_all_instructors_response( $instructors );
		wp_send_json_success( $results );
		wp_die();
	}

	public function get_all_students() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}
		$students = \Academy\Helper::get_all_students();
		$students = \Academy\Helper::prepare_get_all_students_response( $students );
		wp_send_json_success( $students );
		wp_die();
	}

	public function get_instructors_by_course_id() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}
		$course_id = (int) sanitize_text_field( $_POST['course_id'] );
		$results   = [];
		if ( $course_id ) {
			$results = \Academy\Helper::get_instructors_by_course_id( $course_id );
		} else {
			$results = \Academy\Helper::get_current_instructor();
			$results = \Academy\Helper::prepare_all_instructors_response( $results );
		}
		if ( $results ) {
			wp_send_json_success( $results );
			wp_die();
		}
		wp_send_json_error( $results );
		wp_die();
	}
	public function get_course_ids_by_instructor_id() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_academy_instructor' ) ) {
			wp_die();
		}
		$instructor_id = (int) sanitize_text_field( $_POST['instructor_id'] );
		$results       = [];
		if ( $instructor_id ) {
			$results = \Academy\Helper::get_course_ids_by_instructor_id( $instructor_id );
		}
		wp_send_json_success( $results );
		wp_die();
	}
	public function remove_instructor_from_course() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}
		$course_id     = (int) sanitize_text_field( $_POST['course_id'] );
		$instructor_id = (int) sanitize_text_field( $_POST['instructor_id'] );
		$is_delete     = delete_user_meta( $instructor_id, 'academy_instructor_course_id', $course_id );
		if ( $is_delete ) {
			wp_send_json_success( $is_delete );
			wp_die();
		}
		wp_send_json_error( $is_delete );
		wp_die();
	}
	public function get_all_withdraw_request() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}
		$results = \Academy\Helper::get_withdraw_request();
		wp_send_json_success( $results );
		wp_die();
	}
	public function update_withdraw_status() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}
		$data      = \Academy\Helper::fresh_ajax_request_data( $_POST );
		$data      = \Academy\Helper::sanitize_text_or_array_field( $data );
		$is_update = \Academy\Helper::update_withdraw_status_by_withdraw_id( $data['ID'], $data['statusTo'] );
		if ( $is_update ) {
			$results = \Academy\Helper::get_withdraw_by_withdraw_id( $data['ID'] );
			wp_send_json_success( current( $results ) );
			wp_die();
		}
		wp_send_json_error( [ 'message' => esc_html__( 'Failed to update withdraw status', 'academy' ) ] );
		wp_die();
	}
	public function get_course_slug() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'edit_posts' ) ) {
			wp_die();
		}
		$post_id = ( isset( $_POST['ID'] ) ? $_POST['ID'] : '' );
		$title   = isset( $_POST['new_title'] ) ? $_POST['new_title'] : '';
		$slug    = isset( $_POST['new_slug'] ) ? $_POST['new_slug'] : null;

		wp_send_json_success( Academy\Helper::get_sample_permalink_args( $post_id, $title, $slug ) );
		wp_die();
	}
}
