<?php
namespace Academy\Admin;

use Academy;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Course {
	public static function init() {
		$self = new self();
		add_action( 'admin_post_academy_course_enroll', [ $self, 'academy_course_enroll' ] );
		add_action( 'admin_post_nopriv_academy_course_enroll', [ $self, 'academy_course_enroll' ] );
		add_action( 'admin_post_academy_course_complete', [ $self, 'academy_course_complete' ] );
	}
	public function academy_course_enroll() {
		if ( isset( $_REQUEST['_wpnonce'] ) && wp_verify_nonce( $_REQUEST['_wpnonce'], 'academy_course_enroll_now' ) ) {

			$user_id = get_current_user_id();
			if ( ! $user_id ) {
				if ( wp_safe_redirect( wp_login_url( wp_get_referer() ) ) ) {
					exit;
				}
			}

			$course_id = (int) sanitize_text_field( $_POST['academy_course_id'] );

			\Academy\Helper::do_enroll( $course_id, $user_id );

			$referer_url = wp_get_referer();
			wp_safe_redirect( $referer_url );
		} else {
			die( esc_html__( 'Security check', 'academy' ) );
		}
	}
	public function academy_course_complete() {
		if ( isset( $_REQUEST['_wpnonce'] ) && wp_verify_nonce( $_REQUEST['_wpnonce'], 'academy_course_complete_now' ) ) {

			$user_id = get_current_user_id();
			if ( ! $user_id ) {
				if ( wp_safe_redirect( wp_login_url( wp_get_referer() ) ) ) {
					exit;
				}
			}
			$course_id = (int) sanitize_text_field( $_POST['academy_course_id'] );

			do_action( 'academy/admin/course_complete_before', $course_id );

			global $wpdb;
			$date = gmdate( 'Y-m-d H:i:s', \Academy\Helper::get_time() );

			// hash is unique.
			do {
				$hash    = substr( md5( wp_generate_password( 32 ) . $date . $course_id . $user_id ), 0, 16 );
				$hasHash = (int) $wpdb->get_var(
					$wpdb->prepare(
						"SELECT COUNT(comment_ID) from {$wpdb->comments} 
                    WHERE comment_agent = 'academy' AND comment_type = 'course_completed' AND comment_content = %s ",
						$hash
					)
				);

			} while ( $hasHash > 0 );

			$data = array(
				'comment_post_ID'  => $course_id,
				'comment_author'   => $user_id,
				'comment_date'     => $date,
				'comment_date_gmt' => get_gmt_from_date( $date ),
				'comment_content'  => $hash,
				'comment_approved' => 'approved',
				'comment_agent'    => 'academy',
				'comment_type'     => 'course_completed',
				'user_id'          => $user_id,
			);
			$wpdb->insert( $wpdb->comments, $data );

			do_action( 'academy/admin/course_complete_after', $course_id, $user_id );

			$referer_url = wp_get_referer();
			wp_safe_redirect( $referer_url );
		} else {
			die( esc_html__( 'Security check', 'academy' ) );
		}//end if
	}
}
