<?php
namespace Academy\Admin;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Registration {
	public static function init() {
		$self = new self();
		add_action( 'admin_post_nopriv_academy_instructor_registration', [ $self, 'instructor_registration' ] );
		add_action( 'admin_post_nopriv_academy_student_registration', [ $self, 'student_registration' ] );
	}

	public function instructor_registration() {
		if ( isset( $_REQUEST['_wpnonce'] ) && wp_verify_nonce( $_REQUEST['_wpnonce'], 'academy_instructor_registration_nonce' ) ) {

			$first_name       = sanitize_text_field( $_POST['first_name'] );
			$last_name        = sanitize_text_field( $_POST['last_name'] );
			$user_name        = sanitize_text_field( $_POST['user_name'] );
			$email            = sanitize_text_field( $_POST['email'] );
			$password         = sanitize_text_field( $_POST['password'] );
			$confirm_password = sanitize_text_field( $_POST['confirm_password'] );

			if ( empty( $user_name ) || empty( $email ) || $password !== $confirm_password ) {
				return;
			}

			$userdata = array(
				'user_login' => $user_name,
				'user_email' => $email,
				'first_name' => $first_name,
				'last_name'  => $last_name,
				'user_pass'  => $password,
			);
			do_action( 'academy/admin/before_instructor_registration', $userdata );

			$user_id = wp_insert_user( $userdata );
			if ( ! is_wp_error( $user_id ) ) {
				update_user_meta( $user_id, 'is_academy_instructor', \Academy\Helper::get_time() );
				update_user_meta( $user_id, 'academy_instructor_status', apply_filters( 'academy/admin/registration_instructor_status', 'pending' ) );

				do_action( 'academy/admin/after_instructor_registration', $user_id );

				$user = get_user_by( 'id', $user_id );
				if ( $user ) {
					wp_set_current_user( $user_id, $user->user_login );
					wp_set_auth_cookie( $user_id );
				}
			}

			$referer_url = wp_get_referer();
			wp_safe_redirect( $referer_url );
		} else {
			die( esc_html__( 'Security check', 'academy' ) );
		}//end if
	}

	public function student_registration() {
		if ( isset( $_REQUEST['_wpnonce'] ) && wp_verify_nonce( $_REQUEST['_wpnonce'], 'academy_student_registration_nonce' ) ) {

			$first_name       = sanitize_text_field( $_POST['first_name'] );
			$last_name        = sanitize_text_field( $_POST['last_name'] );
			$user_name        = sanitize_text_field( $_POST['user_name'] );
			$email            = sanitize_text_field( $_POST['email'] );
			$password         = sanitize_text_field( $_POST['password'] );
			$confirm_password = sanitize_text_field( $_POST['confirm_password'] );

			if ( empty( $user_name ) || empty( $email ) || $password !== $confirm_password ) {
				return;
			}

			$userdata = array(
				'user_login' => $user_name,
				'user_email' => $email,
				'first_name' => $first_name,
				'last_name'  => $last_name,
				'user_pass'  => $password,
				'role'       => 'academy_student',
			);
			do_action( 'academy/admin/before_student_registration', $userdata );

			$user_id = wp_insert_user( $userdata );
			if ( ! is_wp_error( $user_id ) ) {
				do_action( 'academy/admin/after_student_registration', $user_id );

				$user = get_user_by( 'id', $user_id );
				if ( $user ) {
					wp_set_current_user( $user_id, $user->user_login );
					wp_set_auth_cookie( $user_id );
				}
			}

			$referer_url = wp_get_referer();
			wp_safe_redirect( $referer_url );
		} else {
			die( esc_html__( 'Security check', 'academy' ) );
		}//end if
	}
}
