<?php
namespace Academy\Admin\Settings;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Config {

	public function __construct( $config ) {
		$this->get_config( $config );
	}
	public function get_config( $config ) {
		$pages = wp_list_pluck( get_pages(), 'post_title', 'ID' );
		// build settings
		$config::add_tab(
			[
				'title' => __( 'General', 'academy' ),
				'id'    => 'general',
			]
		);
		$config::add_field(
			'general',
			[
				'id'      => 'frontend_dashboard_page',
				'type'    => 'select',
				'title'   => __( 'Dashboard Page', 'academy' ),
				'default' => '',
				'options' => $pages,
			]
		);
		$config::add_field(
			'general',
			[
				'id'      => 'is_enabled_academy_web_font',
				'type'    => 'checkbox',
				'title'   => __( 'Load Academy Font', 'academy' ),
				'desc'    => __( 'if you want to apply your theme font with your theme own style then disable it.', 'academy' ),
				'default' => true,
			]
		);
		// design
		$config::add_tab(
			[
				'title' => __( 'Design', 'academy' ),
				'id'    => 'design',
			]
		);
		$config::add_field(
			'design',
			[
				'id'            => 'customizer_all_settings',
				'type'          => 'customizershortcutlists',
				'data'      => array(
					array(
						'icon'          => 'dashicons dashicons-admin-customizer',
						'title'         => __( 'Course Single Styles', 'academy' ),
						'desc'          => __( 'Set course single page spacing and colors.', 'academy' ),
						'url'           => esc_url( admin_url( '/customize.php?autofocus[section]=academy_single_course' ) ),
					),
					array(
						'icon'          => 'dashicons dashicons-admin-settings',
						'title'         => __( 'Course Archive Settings', 'academy' ),
						'desc'          => __( 'Shorting or hide filter and manage query settings.', 'academy' ),
						'url'           => esc_url( admin_url( '/customize.php?autofocus[section]=academy_archive_course' ) ),
					),
					array(
						'icon'          => 'dashicons dashicons-admin-appearance',
						'title'         => __( 'Course Archive Styles', 'academy' ),
						'desc'          => __( 'Set course archive page spacing and colors.', 'academy' ),
						'url'           => esc_url( admin_url( '/customize.php?autofocus[section]=academy_archive_course' ) ),
					),
				),
			]
		);
		// course
		$config::add_tab(
			[
				'title' => __( 'Course', 'academy' ),
				'id'    => 'course',
			]
		);
		$config::add_field(
			'course',
			[
				'id'      => 'course_page',
				'type'    => 'select',
				'title'   => __( 'Course Page', 'academy' ),
				'default' => '',
				'options' => $pages,
			]
		);
		$config::add_field(
			'course',
			[
				'id'            => 'course_page_adv_settings',
				'type'          => 'customizershortcut',
				'title'         => __( 'Course Archive Options', 'academy' ),
				'desc'          => __( 'Set Course Archive Page filter, color option and more.', 'academy' ),
				'url'           => esc_url( admin_url( '/customize.php?autofocus[section]=academy_archive_course' ) ),
			]
		);
		$config::add_field(
			'course',
			[
				'id'            => 'course_page_adv_settings',
				'type'          => 'customizershortcut',
				'title'         => __( 'Course Details Options', 'academy' ),
				'desc'          => __( 'Set Course Details Page color option.', 'academy' ),
				'url'           => esc_url( admin_url( '/customize.php?autofocus[section]=academy_single_course' ) ),
			]
		);
		// instructors
		$config::add_tab(
			[
				'title' => __( 'Instructors', 'academy' ),
				'id'    => 'instructors',
			]
		);
		$config::add_field(
			'instructors',
			[
				'id'      => 'frontend_instructor_reg_page',
				'type'    => 'select',
				'title'   => __( 'Instructor Registration Page', 'academy' ),
				'default' => '',
				'options' => $pages,
			]
		);
		$config::add_field(
			'instructors',
			[
				'id'      => 'is_show_public_profile',
				'type'    => 'checkbox',
				'title'   => __( 'Public Profile', 'academy' ),
				'desc'    => __( 'Enable Instructor Public Profile. Example: ', 'academy' ) . site_url( '/author/admin' ),
				'default' => true, // 1 = on | 0 = off
			]
		);
		$config::add_field(
			'instructors',
			[
				'id'      => 'is_instructor_can_publish_course',
				'type'    => 'checkbox',
				'title'   => __( 'Allow publishing course', 'academy' ),
				'desc'    => __( 'Enable instructors to publish course directly.', 'academy' ),
				'default' => false, // 1 = on | 0 = off
			]
		);
		// student
		$config::add_tab(
			[
				'title' => __( 'Student', 'academy' ),
				'id'    => 'student',
			]
		);
		$config::add_field(
			'student',
			[
				'id'      => 'frontend_student_reg_page',
				'type'    => 'select',
				'title'   => __( 'Student Registration Page', 'academy' ),
				'default' => '',
				'options' => $pages,
			]
		);
		$config::add_field(
			'student',
			[
				'id'      => 'is_student_can_upload_files',
				'type'    => 'checkbox',
				'title'   => __( 'Allow upload files', 'academy' ),
				'desc'    => __( 'Enable student upload files.', 'academy' ),
				'default' => true, // 1 = on | 0 = off
			]
		);
		// Earning
		$this->get_earning_settings( $config );
		$this->get_withdrawal_settings( $config );
		// woocommerce
		$config::add_tab(
			[
				'title' => __( 'Woocommerce', 'academy' ),
				'id'    => 'woocommerce',
			]
		);
		$config::add_field(
			'woocommerce',
			[
				'id'      => 'hide_course_from_shop_page',
				'type'    => 'checkbox',
				'title'   => __( 'Course Product', 'academy' ),
				'desc'    => __( 'Hide course products from shop page', 'academy' ),
				'default' => false, // 1 = on | 0 = off
			]
		);
		$config::add_field(
			'woocommerce',
			[
				'id'      => 'is_enabled_fd_link_inside_woo_dashboard',
				'type'    => 'checkbox',
				'title'   => __( 'Enable/Disable', 'academy' ),
				'desc'    => __( 'Enable Course Dashboard Link inside My Account Page.', 'academy' ),
				'default' => true,
			]
		);
		$config::add_field(
			'woocommerce',
			[
				'id'        => 'woo_dashboard_fd_link_label',
				'type'      => 'text',
				'title'     => __( 'My Account Link Label', 'academy' ),
				'default'   => esc_html__( 'Courses Dashboard', 'academy' ),
				'condition' => [
					'is_enabled_fd_link_inside_woo_dashboard' => true,
				],
			]
		);
		$config::add_field(
			'woocommerce',
			[
				'id'      => 'is_enabled_fd_link_inside_woo_order_page',
				'type'    => 'checkbox',
				'title'   => __( 'Course Dashboard Button', 'academy' ),
				'desc'    => __( 'Enable/Disable Course Dashboard Button (it will be showing inside order details page)', 'academy' ),
				'default' => true,
			]
		);
		$config::add_field(
			'woocommerce',
			[
				'id'        => 'woo_order_page_fd_link_label',
				'type'      => 'text',
				'title'     => __( 'Course Dashboard Button Text', 'academy' ),
				'desc'    => __( 'Add Course Dashboard Button Text (it will be showing inside order details page)', 'academy' ),
				'default'   => esc_html__( 'Courses Dashboard', 'academy' ),
				'condition' => [
					'is_enabled_fd_link_inside_woo_order_page' => true,
				],
			]
		);
	}
	public function get_earning_settings( $config ) {
		$config::add_tab(
			[
				'title' => __( 'Earning', 'academy' ),
				'id'    => 'earning',
			]
		);
		$config::add_field(
			'earning',
			[
				'id'      => 'is_enabled_earning',
				'type'    => 'checkbox',
				'title'   => __( 'Enable Earning', 'academy' ),
				'desc'    => __( 'If disabled, the Admin will receive 100% of the earning', 'academy' ),
				'default' => true, // 1 = on | 0 = off
			]
		);
		$config::add_field(
			'earning',
			[
				'id'        => 'admin_commission_percentage',
				'type'      => 'number',
				'title'     => __( 'Admin Commission Percentage', 'academy' ),
				'desc'      => __( 'Define the commission of the Admin from each sale.(after deducting fees)', 'academy' ),
				'default'   => 20,
				'condition' => [
					'is_enabled_earning' => true,
				],
			]
		);
		$config::add_field(
			'earning',
			[
				'id'        => 'instructor_commission_percentage',
				'type'      => 'number',
				'title'     => __( 'Instructor Commission Percentage', 'academy' ),
				'desc'      => __( 'Define the commission for instructors from each sale.(after deducting fees)', 'academy' ),
				'default'   => 80,
				'condition' => [
					'is_enabled_earning' => true,
				],
			]
		);
		$config::add_field(
			'earning',
			[
				'id'      => 'is_enabled_fee_deduction',
				'type'    => 'checkbox',
				'title'   => __( 'Eanable Fee Deduction', 'academy' ),
				'desc'    => __( 'Fees are charged from the entire sales amount. The remaining amount will be divided among admin and instructors.', 'academy' ),
				'default' => true, // 1 = on | 0 = off
			]
		);
		$config::add_field(
			'earning',
			[
				'id'        => 'fee_deduction_name',
				'type'      => 'text',
				'title'     => __( 'Fee Deduction Name', 'academy' ),
				'default'   => '',
				'condition' => [
					'is_enabled_fee_deduction' => true,
				],
			]
		);
		$config::add_field(
			'earning',
			[
				'id'        => 'fee_deduction_amount',
				'type'      => 'number',
				'title'     => __( 'Fee Deduction Amount', 'academy' ),
				'default'   => '',
				'condition' => [
					'is_enabled_fee_deduction' => true,
				],
			]
		);
		$config::add_field(
			'earning',
			[
				'id'        => 'fee_deduction_type',
				'type'      => 'select',
				'title'     => __( 'Fee Deduction Type', 'academy' ),
				'default'   => 'percent',
				'options'   => [
					'percent' => __( 'Percent', 'academy' ),
					'fixed'   => __( 'Fixed', 'academy' ),
				],
				'condition' => [
					'is_enabled_fee_deduction' => true,
				],
			]
		);
	}
	public function get_withdrawal_settings( $config ) {
		$config::add_tab(
			[
				'title' => __( 'Withdrawal', 'academy' ),
				'id'    => 'withdrawal',
			]
		);
		$config::add_field(
			'withdrawal',
			[
				'id'      => 'instructor_minimum_withdraw_amount',
				'type'    => 'number',
				'title'   => __( 'Minimum Withdraw Amount', 'academy' ),
				'desc'    => __( 'Instructors should earn equal or above this amount to make a withdraw request.', 'academy' ),
				'default' => 80,
			]
		);
		$config::add_field(
			'withdrawal',
			[
				'id'      => 'is_enabled_instructor_paypal_withdraw',
				'type'    => 'checkbox',
				'title'   => __( 'Enable/Disable', 'academy' ),
				'desc'    => __( 'Enable PayPal', 'academy' ),
				'default' => true,
			]
		);
		$config::add_field(
			'withdrawal',
			[
				'id'      => 'is_enabled_instructor_echeck_withdraw',
				'type'    => 'checkbox',
				'title'   => __( 'Enable/Disable', 'academy' ),
				'desc'    => __( 'Enable E-Check', 'academy' ),
				'default' => false,
			]
		);
		$config::add_field(
			'withdrawal',
			[
				'id'      => 'is_enabled_instructor_bank_withdraw',
				'type'    => 'checkbox',
				'title'   => __( 'Enable/Disable', 'academy' ),
				'desc'    => __( 'Enable Bank Transfer', 'academy' ),
				'default' => false,
			]
		);
		$config::add_field(
			'withdrawal',
			[
				'id'        => 'instructor_bank_withdraw_instruction',
				'type'      => 'textarea',
				'title'     => __( 'Instruction', 'academy' ),
				'desc'      => __( 'Write instruction for the instructor to fill bank information', 'academy' ),
				'default'   => '',
				'condition' => [
					'is_enabled_instructor_bank_withdraw' => true,
				],
			]
		);
	}
}
