<?php
namespace Academy\API;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Academy\API\Controller;

class Settings extends Controller {

	/**
	 * Initialize hooks and option name
	 */
	public static function init() {
		$self = new self();
		add_action( 'rest_api_init', array( $self, 'register_routes' ) );
		add_action( 'academy/api/settings/after_save_settings', array( $self, 'after_save_settings' ) );
	}

	/**
	 * Register the routes for the objects of the controller.
	 */
	public function register_routes() {
		$endpoint = '/settings/';

		register_rest_route(
			$this->namespace,
			$endpoint,
			array(
				array(
					'methods'             => \WP_REST_Server::READABLE,
					'callback'            => array( $this, 'get_value' ),
					'permission_callback' => array( $this, 'permissions_check' ),
					'args'                => array(),
				),
			)
		);

		register_rest_route(
			$this->namespace,
			$endpoint,
			array(
				array(
					'methods'             => \WP_REST_Server::CREATABLE,
					'callback'            => array( $this, 'create_value' ),
					'permission_callback' => array( $this, 'permissions_check' ),
					'args'                => array(),
				),
			)
		);

		register_rest_route(
			$this->namespace,
			$endpoint,
			array(
				array(
					'methods'             => \WP_REST_Server::EDITABLE,
					'callback'            => array( $this, 'update_value' ),
					'permission_callback' => array( $this, 'permissions_check' ),
					'args'                => array(),
				),
			)
		);

		register_rest_route(
			$this->namespace,
			$endpoint,
			array(
				array(
					'methods'             => \WP_REST_Server::DELETABLE,
					'callback'            => array( $this, 'delete_value' ),
					'permission_callback' => array( $this, 'permissions_check' ),
					'args'                => array(),
				),
			)
		);
	}

	/**
	 * Get wprs
	 *
	 * @param WP_REST_Request $request Full data about the request.
	 * @return WP_Error|WP_REST_Request
	 */
	public function get_value( $request ) {
		$wprs_option = get_option( ACADEMY_SETTINGS_NAME );
		// Don't return false if there is no option
		if ( ! $wprs_option ) {
			return new \WP_REST_Response(
				array(
					'success' => true,
					'value'   => '',
				),
				200
			);
		}

		return new \WP_REST_Response(
			array(
				'success' => true,
				'value'   => $wprs_option,
			),
			200
		);
	}

	/**
	 * Create OR Update wprs
	 *
	 * @param WP_REST_Request $request Full data about the request.
	 * @return WP_Error|WP_REST_Request
	 */
	public function create_value( $request ) {
		$data = json_decode( $request->get_param( 'wprsSetting' ), true );
		$updated = update_option( ACADEMY_SETTINGS_NAME, wp_json_encode( $data ), false );
		do_action( 'academy/api/settings/after_save_settings', $updated );
		return new \WP_REST_Response(
			array(
				'success' => $updated,
				'value'   => $request->get_param( 'wprsSetting' ),
			),
			200
		);
	}

	/**
	 * Create OR Update wprs
	 *
	 * @param WP_REST_Request $request Full data about the request.
	 * @return WP_Error|WP_REST_Request
	 */
	public function update_value( $request ) {
		$data = json_decode( $request->get_param( 'wprsSetting' ), true );
		$updated = update_option( ACADEMY_SETTINGS_NAME, wp_json_encode( $data ), false );
		do_action( 'academy/api/settings/after_save_settings', $updated );
		return new \WP_REST_Response(
			array(
				'success' => $updated,
				'value'   => $request->get_param( 'wprsSetting' ),
			),
			200
		);
	}

	/**
	 * Delete wprs
	 *
	 * @param WP_REST_Request $request Full data about the request.
	 * @return WP_Error|WP_REST_Request
	 */
	public function delete_value( $request ) {
		$deleted = delete_option( ACADEMY_SETTINGS_NAME );

		return new \WP_REST_Response(
			array(
				'success' => $deleted,
				'value'   => '',
			),
			200
		);
	}

	/**
	 * Check if a given request has access to update a setting
	 *
	 * @param WP_REST_Request $request Full data about the request.
	 * @return WP_Error|bool
	 */
	public function permissions_check( $request ) {
		return current_user_can( 'manage_options' );
	}

	public function after_save_settings( $is_changed_settings ) {
		if ( $is_changed_settings ) {
			update_option( 'academy_flash_role_management', true );
		}
	}
}
