<?php
namespace Academy;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
class Assets {

	public static function init() {
		$self = new self();
		add_action( 'admin_enqueue_scripts', [ $self, 'backend_scripts' ] );
		add_action( 'wp_enqueue_scripts', [ $self, 'frontend_scripts' ] );
	}

	private function get_scripts_data() {
		return array(
			'nonce'                 => wp_create_nonce( 'wp_rest' ),
			'academy_nonce'         => wp_create_nonce( 'academy_nonce' ),
			'rest_url'              => rest_url(),
			'namespace'             => ACADEMY_PLUGIN_SLUG . '/v1/',
			'plugin_root_url'       => ACADEMY_PLUGIN_ROOT_URI,
			'plugin_root_path'      => ACADEMY_ROOT_DIR_PATH,
			'ajaxurl'               => esc_url( admin_url( 'admin-ajax.php' ) ),
			'site_url'              => site_url(),
			'route_path'            => wp_parse_url( admin_url(), PHP_URL_PATH ),
			'menu'                  => wp_json_encode( Helper::get_admin_menu_list() ),
			'settings'              => Helper::get_settings_assets_data(),
			'woocommerce_is_active' => Helper::is_active_woocommerce(),
			'current_user_id'       => get_current_user_id(),
			'is_rtl'				=> is_rtl(),
			'current_user_can'      => [
				'manage_options'            => current_user_can( 'manage_options' ),
				'manage_academy_instructor' => current_user_can( 'manage_academy_instructor' ),
				'publish_academy_courses'   => current_user_can( 'publish_academy_courses' ),
			],
		);
	}

	private function get_backend_scripts_data() {
		return apply_filters( 'academy/assets/backend_scripts_data', $this->get_scripts_data() );
	}

	private function get_frontend_scripts_data() {
		$site_url = site_url();
		return apply_filters(
			'academy/assets/fronted_scripts_data',
			array_merge(
				$this->get_scripts_data(),
				array(
					'route_path' => wp_parse_url( $site_url, PHP_URL_PATH ),
					'admin_url'  => admin_url(),
					'dashboard'  => trim( get_permalink( Helper::get_settings( 'frontend_dashboard_page' ) ), $site_url ),
					'logout_url' => wp_logout_url( home_url( '/' ) ),
				)
			)
		);
	}

	/**
	 * Enqueue Files on Start Plugin
	 *
	 * @param string $hook
	 * @function backend_scripts
	 */
	public function backend_scripts( $hook ) {
		if ( \Academy\Helper::plugin_page_hook_suffix( $hook ) ) {
			$wp_includes_url = site_url( '/' . WPINC );
			// phpcs:ignore WordPress.WP.EnqueuedResourceParameters.MissingVersion
			wp_enqueue_style( 'academy-editor', $wp_includes_url . '/css/editor.css' );
			wp_enqueue_style( 'academy-icon', ACADEMY_ASSETS_URI . 'lib/css/academy-icon.css', array(), filemtime( ACADEMY_ASSETS_DIR_PATH . 'lib/css/academy-icon.css' ), 'all' );
			wp_enqueue_style( 'academy-admin-style', ACADEMY_ASSETS_URI . 'css/backend.css', array( 'wp-components' ), filemtime( ACADEMY_ASSETS_DIR_PATH . 'css/backend.css' ), 'all' );
			// js
			$dependencies = include_once ACADEMY_ASSETS_DIR_PATH . 'js/backend.asset.php';
			if ( ! did_action( 'wp_enqueue_media' ) ) {
				wp_enqueue_media();
			}
			wp_enqueue_script( 'academy-tinymce-editor', $wp_includes_url . '/js/tinymce/wp-tinymce.js', array( 'jquery' ), $dependencies['version'], true );
			wp_enqueue_script(
				'academy-admin-scripts',
				ACADEMY_ASSETS_URI . 'js/backend.js',
				$dependencies['dependencies'],
				$dependencies['version'],
				true
			);
			wp_localize_script( 'academy-admin-scripts', 'AcademyGlobal', $this->get_backend_scripts_data() );
			wp_set_script_translations( 'academy-admin-scripts', 'academy', ACADEMY_ROOT_DIR_PATH . 'languages/' );
		}//end if
	}
	/**
	 * Enqueue Files on Start Plugin
	 *
	 * @function frontend_scripts
	 */
	public function frontend_scripts() {
		if ( apply_filters( 'academy/load_frontend_scritps', $this->is_academy_pages() ) === false ) {
			return;
		}
		if ( Helper::get_settings( 'is_enabled_academy_web_font' ) ) {
			// phpcs:ignore WordPress.WP.EnqueuedResourceParameters.MissingVersion
			wp_enqueue_style( 'academy-web-font', $this->web_fonts_url( 'Inter:wght@300;400;500;600;700;800;900|Montserrat:ital,wght@0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap' ), array() );
		}
		wp_enqueue_style( 'academy-jquery-modal', ACADEMY_ASSETS_URI . 'lib/css/jquery.modal.min.css', array(), filemtime( ACADEMY_ASSETS_DIR_PATH . 'lib/css/jquery.modal.min.css' ), 'all' );
		wp_enqueue_style( 'academy-icon', ACADEMY_ASSETS_URI . 'lib/css/academy-icon.css', array(), filemtime( ACADEMY_ASSETS_DIR_PATH . 'lib/css/academy-icon.css' ), 'all' );
		wp_enqueue_style( 'academy-plyr', ACADEMY_ASSETS_URI . 'lib/css/plyr.css', array(), filemtime( ACADEMY_ASSETS_DIR_PATH . 'lib/css/plyr.css' ), 'all' );
		wp_enqueue_style( 'academy-frontend-style', ACADEMY_ASSETS_URI . 'css/frontend.css', array( 'wp-components' ), filemtime( ACADEMY_ASSETS_DIR_PATH . 'css/frontend.css' ), 'all' );
		// js
		$dependencies = include_once ACADEMY_ASSETS_DIR_PATH . 'js/frontend.asset.php';
		if ( ! did_action( 'wp_enqueue_media' ) ) {
			wp_enqueue_media();
		}
		wp_enqueue_script( 'academy-jquery-modal', ACADEMY_ASSETS_URI . 'lib/js/jquery.modal.min.js', array( 'jquery' ), $dependencies['version'], false );
		wp_enqueue_script( 'academy-sticksy', ACADEMY_ASSETS_URI . 'lib/js/sticksy.min.js', array( 'jquery' ), $dependencies['version'], false );
		wp_enqueue_script( 'academy-plyr', ACADEMY_ASSETS_URI . 'lib/js/plyr.js', array( 'jquery' ), $dependencies['version'], false );
		wp_enqueue_script( 'academy-SocialShare', ACADEMY_ASSETS_URI . 'lib/js/SocialShare.min.js', array( 'jquery' ), $dependencies['version'], false );
		wp_enqueue_script(
			'academy-frontend-scripts',
			ACADEMY_ASSETS_URI . 'js/frontend.js',
			$dependencies['dependencies'],
			$dependencies['version'],
			true
		);
		wp_localize_script( 'academy-frontend-scripts', 'AcademyGlobal', $this->get_frontend_scripts_data() );
		wp_set_script_translations( 'academy-frontend-scripts', 'academy', ACADEMY_ROOT_DIR_PATH . 'languages/' );
	}

	public function is_academy_pages() {
		global $post;
		if (
			is_post_type_archive( 'academy_courses' ) ||
			$post &&
			(
				get_post_type( $post->ID ) === 'academy_courses' ||
				(int) \Academy\Helper::get_settings( 'frontend_dashboard_page' ) === $post->ID ||
				(int) \Academy\Helper::get_settings( 'course_page' ) === $post->ID ||
				(int) \Academy\Helper::get_settings( 'frontend_instructor_reg_page' ) === $post->ID ||
				(int) \Academy\Helper::get_settings( 'frontend_student_reg_page' ) === $post->ID ||
				has_shortcode( $post->post_content, 'academy_courses' ) ||
				has_shortcode( $post->post_content, 'academy_dashboard' ) ||
				has_shortcode( $post->post_content, 'academy_instructor_registration_form' ) ||
				has_shortcode( $post->post_content, 'academy_student_registration_form' )
			)
		) {
			return true;
		}
		return false;
	}


	public function web_fonts_url( $font ) {
		$font_url = '';
		if ( 'off' !== _x( 'on', 'Google font: on or off', 'academy' ) ) {
			$font_url = add_query_arg( 'family', rawurlencode( $font ), '//fonts.googleapis.com/css' );
		}
		return $font_url;
	}
}
