<?php
namespace Academy;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
class Database {

	public static function init() {
		$self = new self();
		add_action( 'init', [ $self, 'create_initial_post_types' ] );
		add_action( 'rest_api_init', [ $self, 'register_course_meta' ] );
	}
	public function create_initial_post_types() {
		$post_type = 'academy_courses';
		register_post_type(
			$post_type,
			array(
				'labels'                => array(
					'name'                  => esc_html__( 'Courses', 'academy' ),
					'singular_name'         => esc_html__( 'Course', 'academy' ),
					'search_items'          => esc_html__( 'Search Courses', 'academy' ),
					'parent_item_colon'     => esc_html__( 'Parent Courses:', 'academy' ),
					'not_found'             => esc_html__( 'No Courses found.', 'academy' ),
					'not_found_in_trash'    => esc_html__( 'No Courses found in Trash.', 'academy' ),
					'archives'              => esc_html__( 'Course archives', 'academy' ),
				),
				'public'                => true,
				'publicly_queryable'    => true,
				'show_ui'               => false,
				'show_in_menu'          => false,
				'map_meta_cap'          => true,
				'hierarchical'          => true,
				'rewrite'               => array( 'slug' => 'course' ),
				'query_var'             => true,
				'has_archive'           => true,
				'delete_with_user'      => false,
				'supports'              => array( 'title', 'editor', 'author', 'thumbnail', 'excerpt', 'trackbacks', 'custom-fields', 'comments', 'post-formats' ),
				'show_in_rest'          => true,
				'rest_base'             => $post_type,
				'rest_controller_class' => '\Academy\API\Controller\Course',
			)
		);

		register_taxonomy(
			$post_type . '_category',
			$post_type,
			array(
				'hierarchical'          => true,
				'query_var'             => 'category_name',
				'rewrite'               => false,
				'public'                => true,
				'show_ui'               => false,
				'show_admin_column'     => false,
				'_builtin'              => true,
				'capabilities'          => array(
					'manage_terms' => 'manage_categories',
					'edit_terms'   => 'edit_categories',
					'delete_terms' => 'delete_categories',
					'assign_terms' => 'assign_categories',
				),
				'show_in_rest'          => true,
				'rest_base'             => $post_type . '_category',
				'rest_controller_class' => '\Academy\API\Controller\Terms',
			)
		);

		register_taxonomy(
			$post_type . '_tag',
			$post_type,
			array(
				'hierarchical'          => false,
				'query_var'             => 'tag',
				'rewrite'               => false,
				'public'                => true,
				'show_ui'               => false,
				'show_admin_column'     => false,
				'_builtin'              => true,
				'capabilities'          => array(
					'manage_terms' => 'manage_post_tags',
					'edit_terms'   => 'edit_post_tags',
					'delete_terms' => 'delete_post_tags',
					'assign_terms' => 'assign_post_tags',
				),
				'show_in_rest'          => true,
				'rest_base'             => $post_type . '_tag',
				'rest_controller_class' => '\Academy\API\Controller\Terms',
			)
		);
	}

	public function register_course_meta() {
		$course_meta = [
			'academy_course_type'               => 'string',
			'academy_course_product_id'         => 'integer',
			'academy_course_max_students'       => 'integer',
			'academy_course_language'           => 'string',
			'academy_course_students_enrolled'  => 'integer',
			'academy_course_difficulty_level'   => 'string',
			'academy_course_benefits'           => 'string',
			'academy_course_requirements'       => 'string',
			'academy_course_audience'           => 'string',
			'academy_course_materials_included' => 'string',
		];

		foreach ( $course_meta as $meta_key => $meta_value_type ) {
			register_meta(
				'post',
				$meta_key,
				array(
					'object_subtype' => 'academy_courses',
					'type'           => $meta_value_type,
					'single'         => true,
					'show_in_rest'   => true,
				)
			);
		}

		register_meta(
			'post',
			'academy_course_duration',
			array(
				'object_subtype' => 'academy_courses',
				'type'           => 'array',
				'single'         => true,
				'show_in_rest'   => [
					'schema' => array(
						'items' => array(
							'type'       => 'integer',
							'properties' => [
								'hours'   => array(
									'type' => 'integer',
								),
								'minutes' => array(
									'type' => 'integer',
								),
								'seconds' => array(
									'type' => 'integer',
								),
							],
						),
					),
				],
			)
		);

		register_meta(
			'post',
			'academy_course_intro_video',
			array(
				'object_subtype' => 'academy_courses',
				'type'           => 'array',
				'single'         => true,
				'show_in_rest'   => [
					'schema' => array(
						'items' => array(
							'type'       => 'string',
							'properties' => [
								'type' => array(
									'type' => 'string',
								),
								'url'  => array(
									'type' => 'string',
								),
							],
						),
					),
				],
			)
		);

		register_meta(
			'post',
			'academy_course_announcements',
			array(
				'object_subtype' => 'academy_courses',
				'type'           => 'array',
				'single'         => true,
				'show_in_rest'   => [
					'schema' => array(
						'items' => array(
							'type'       => 'object',
							'properties' => [
								'title'   => array(
									'type' => 'string',
								),
								'content' => array(
									'type' => 'string',
								),
							],
						),
					),
				],
			)
		);

		register_meta(
			'post',
			'academy_course_curriculum',
			array(
				'object_subtype' => 'academy_courses',
				'type'           => 'array',
				'single'         => true,
				'show_in_rest'   => [
					'schema' => array(
						'items' => array(
							'type'       => 'object',
							'properties' => [
								'topics'  => array(
									'type'  => 'array',
									'items' => array(
										'type'       => 'object',
										'properties' => array(
											'id'   => array(
												'type' => 'string',
											),
											'name' => array(
												'type' => 'string',
											),
											'type' => array(
												'type' => 'string',
											),
										),
									),
								),
								'title'   => array(
									'type' => 'string',
								),
								'content' => array(
									'type' => 'string',
								),
							],
						),
					),
				],
			)
		);
	}

	public static function create_initial_custom_table() {
		require_once ABSPATH . 'wp-admin/includes/upgrade.php';
		global $wpdb;
		$prefix          = $wpdb->prefix;
		$charset_collate = $wpdb->get_charset_collate();
		Database\CreateLessonsTable::up( $prefix, $charset_collate );
		Database\CreateLessonMetaTable::up( $prefix, $charset_collate );
		Database\CreateEarningsTable::up( $prefix, $charset_collate );
		Database\CreateWithdrawsTable::up( $prefix, $charset_collate );
	}
}
