<?php
namespace Academy\Frontend;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Ajax {

	public static function init() {
		$self = new self();
		add_action( 'wp_ajax_academy/frontend/render_lesson', array( $self, 'render_lesson' ) );
		add_action( 'wp_ajax_academy/frontend/mark_lesson_complete', array( $self, 'mark_lesson_complete' ) );
		add_action( 'wp_ajax_academy/frontend/render_enrolled_courses', array( $self, 'render_enrolled_courses' ) );
		add_action( 'wp_ajax_nopriv_academy/frontend/render_enrolled_courses', array( $self, 'render_enrolled_courses' ) );
		add_action( 'wp_ajax_academy/frontend/render_wishlist_courses', array( $self, 'render_wishlist_courses' ) );
		add_action( 'wp_ajax_academy/frontend/render_popup_lesson', array( $self, 'render_popup_lesson' ) );
		add_action( 'wp_ajax_nopriv_academy/frontend/render_popup_lesson', array( $self, 'render_popup_lesson' ) );
		add_action( 'wp_ajax_nopriv_academy/frontend/course_add_to_wishlist', array( $self, 'course_add_to_wishlist' ) );
		add_action( 'wp_ajax_academy/frontend/course_add_to_wishlist', array( $self, 'course_add_to_wishlist' ) );
		add_action( 'wp_ajax_academy/frontend/saved_user_info', array( $self, 'saved_user_info' ) );
		add_action( 'wp_ajax_academy/frontend/reset_password', array( $self, 'reset_password' ) );
		add_action( 'wp_ajax_academy/frontend/get_user_given_reviews', array( $self, 'get_user_given_reviews' ) );
		add_action( 'wp_ajax_academy/frontend/get_user_received_reviews', array( $self, 'get_user_received_reviews' ) );
		add_action( 'wp_ajax_academy/frontend/get_user_purchase_histroy', array( $self, 'get_user_purchase_histroy' ) );
		add_action( 'wp_ajax_academy/frontend/archive_course_filter', array( $self, 'archive_course_filter' ) );
		add_action( 'wp_ajax_nopriv_academy/frontend/archive_course_filter', array( $self, 'archive_course_filter' ) );
		// withdraw
		add_action( 'wp_ajax_academy/frontend/get_user_withdraw_info', array( $self, 'get_user_withdraw_info' ) );
		add_action( 'wp_ajax_academy/frontend/get_user_withdraw_settings', array( $self, 'get_user_withdraw_settings' ) );
		add_action( 'wp_ajax_academy/frontend/set_user_withdraw_settings', array( $self, 'set_user_withdraw_settings' ) );
		add_action( 'wp_ajax_academy/frontend/withdraw_request_by_user', array( $self, 'withdraw_request_by_user' ) );
	}

	public function render_lesson() {
		check_admin_referer( 'academy_nonce', 'security' );
		global $wpdb;
		$course_id = (int) sanitize_text_field( $_POST['course_id'] );
		$lesson_id = (int) sanitize_text_field( $_POST['lesson_id'] );
		$user_id   = (int) get_current_user_id();

		$is_administrator = current_user_can( 'administrator' );
		$is_instructor    = \Academy\Helper::is_instructor_of_this_course( $user_id, $course_id );
		$enrolled         = \Academy\Helper::is_enrolled( $course_id, $user_id );

		if ( $is_administrator || $is_instructor || $enrolled ) {
			$lesson = \Academy\Helper::get_lesson( $lesson_id );
			if ( empty( $lesson ) || count( $lesson ) === 0 ) {
				wp_send_json_error( esc_html__( 'Sorry, something went wrong!', 'academy' ) );
				wp_die();
			}
			$lesson = current( $lesson );
			if ( count( $lesson->meta ) > 0 ) {
				if ( isset( $lesson->meta['attachment'] ) && ! empty( $lesson->meta['attachment'] ) ) {
					$lesson->meta['attachment'] = wp_get_attachment_url( $lesson->meta['attachment'] );
				}
				if ( isset( $lesson->meta['video_source'] ) && ! empty( $lesson->meta['video_source'] ) ) {
					$video = $lesson->meta['video_source'];
					if ( 'html5' === $video['type'] && isset( $video['id'] ) ) {
						$attachment_id = (int) $video['id'];
						$att_url       = wp_get_attachment_url( $attachment_id );
						$video['url']  = $att_url;
					} elseif ( 'youtube' === $video['type'] ) {
						$video['url'] = \Academy\Helper::youtube_id_from_url( $video['url'] );
					} elseif ( 'vimeo' === $video['type'] ) {
						$video['url'] = \Academy\Helper::youtube_id_from_url( $video['url'] );
					} elseif ( 'embedded' === $video['type'] ) {
						$video['url'] = \Academy\Helper::parse_embedded_url( $video['url'] );
					} elseif ( 'external' === $video['type'] ) {
						$video['url'] = \Academy\Helper::get_basic_url_to_embed_url( $video['url'] );
					} else {
						$video['type'] = 'external';
						$video['url'] = $video['url'];
					}
					$lesson->meta['video_source'] = $video;
				}
			}//end if
			wp_send_json_success( $lesson );
		}//end if
		wp_send_json_error( esc_html__( 'Access Denied', 'academy' ) );
		wp_die();
	}

	public function mark_lesson_complete() {
		check_admin_referer( 'academy_nonce', 'security' );
		$lesson_id = (int) sanitize_text_field( $_POST['lesson_id'] );
		$user_id   = (int) get_current_user_id();
		$update    = update_user_meta( $user_id, 'academy_completed_topic_id_' . $lesson_id, \Academy\Helper::get_time() );
		wp_send_json_success( $update );
		wp_die();
	}

	public function render_enrolled_courses() {
		check_admin_referer( 'academy_nonce', 'security' );

		$courses = \Academy\Helper::get_enrolled_courses_by_user( get_current_user_id(), array( 'private', 'publish' ) );

		ob_start();
		if ( $courses && $courses->have_posts() ) :
			while ( $courses->have_posts() ) :
				$courses->the_post();
				$ID                      = get_the_ID();
				$rating                  = \Academy\Helper::get_course_rating( $ID );
				$total_lessons           = \Academy\Helper::get_total_number_of_course_lessons( $ID );
				$total_completed_lessons = \Academy\Helper::get_total_number_of_completed_course_lessons( $ID );
				$percentage              = \Academy\Helper::calculate_percentage( $total_lessons, $total_completed_lessons ); ?>
<div class="academy-mycourse academy-mycourse-<?php the_ID(); ?>">
	<div class="academy-mycourse__thumbnail">
				<?php
				if ( has_post_thumbnail() ) {
					the_post_thumbnail( 'medium' );
				} else {
					?>
		<img src="<?php echo esc_url( ACADEMY_ASSETS_URI . '/images/placeholder-300x300.jpg' ); ?>"
			alt="<?php esc_html_e( 'thumbnail', 'academy' ); ?>">
					<?php
				}
				?>
	</div>
	<div class="academy-mycourse__content">
		<div class="academy-course__rating">
				<?php
					// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					echo \Academy\Helper::star_rating_generator( $rating->rating_avg );
				?>
				<?php echo esc_html( $rating->rating_avg ); ?> <span
				class="academy-course__rating-count"><?php echo esc_html( '(' . $rating->rating_count . ')' ); ?></span>
		</div>
		<h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
		<div class="academy-course__meta">
			<div class="academy-course__meta-item"><?php esc_html_e( 'Total Lessons:', 'academy' ); ?><span><?php echo esc_html( $total_lessons ); ?></span></div>
			<div class="academy-course__meta-item"><?php esc_html_e( 'Completed Lessons:', 'academy' ); ?><span><?php echo esc_html( $total_lessons . '/' . $total_completed_lessons ); ?></span>
			</div>
		</div>
		<div class="academy-progress-wrap">
			<div class="academy-progress">
				<div class="academy-progress-bar"
					style="width: <?php echo esc_attr( $percentage ) . '%'; ?>;">
				</div>
			</div>
			<span class="academy-progress-wrap__percent"><?php echo esc_html( $percentage ) . esc_html__( '%  Complete', 'academy' ); ?></span>
		</div>
	</div>
</div>
				<?php
			endwhile;

			wp_reset_query(); else : ?>
				<div class='academy-mycourse'><h3 class='academy-not-found'><?php esc_html_e( 'You haven\'t enrolled course.', 'academy' ); ?></h3></div>
				<?php
		endif;
			$output = ob_get_clean();
			wp_send_json_success( $output );
			wp_die();
	}

	public function render_wishlist_courses() {
		check_admin_referer( 'academy_nonce', 'security' );

		$courses = \Academy\Helper::get_wishlist_courses_by_user( get_current_user_id(), array( 'private', 'publish' ) );

		ob_start();
		?>

<div class="academy-courses">
	<div class="academy-container">
		<div class="academy-row">
			<?php
			if ( $courses && $courses->have_posts() ) :
				while ( $courses->have_posts() ) :
					$courses->the_post();
					\Academy\Helper::get_template_part( 'content', 'course' );
				endwhile;
				wp_reset_query();
			else :
				?>
			<div class='academy-mycourse'>
				<h3 class='academy-not-found'><?php esc_html_e( 'You have no course on the wishlist.', 'academy' ); ?></h3>
			</div>
				<?php
				endif;
			?>
		</div>
	</div>
</div>
		<?php
		$output = ob_get_clean();
		wp_send_json_success( $output );
		wp_die();
	}


	public function render_popup_lesson() {
		check_admin_referer( 'academy_nonce', 'security' );
		$ID             = ( isset( $_GET['ID'] ) ? $_GET['ID'] : '' );
		$is_previewable = (bool) \Academy\Helper::get_lesson_meta( $ID, 'is_previewable' );
		if ( $is_previewable ) {
			$video_source = \Academy\Helper::get_lesson_meta( $ID, 'video_source' );
			if ( 'html5' === $video_source['type'] ) {
				$attr = [
					'width'  => '500px',
					'height' => '290px',
				];
				if ( 'html5' === $video_source['type'] ) {
					$attachment_id = (int) $video_source['id'];
					$att_url       = wp_get_attachment_url( $attachment_id );
					$attr['src']   = $att_url;
					$thumb_id      = get_post_thumbnail_id( $attachment_id );
					if ( ! empty( $thumb_id ) ) {
						$attr['poster'] = wp_get_attachment_url( $thumb_id );
					}
				}
				// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				echo wp_video_shortcode( apply_filters( 'academy/frontend/popup_lesson_arg', $attr ) );
			} elseif ( 'embedded' === $video_source['type'] ) {
				$embed = \Academy\Helper::parse_embedded_url( $video_source['url'] );
				?>
				<iframe width="500" height="290" src="<?php echo esc_url( $embed['url'] ); ?>" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
				<?php
			} else {
				$embed = \Academy\Helper::get_basic_url_to_embed_url( $video_source['url'] );
				?>
				<iframe width="500" height="290" src="<?php echo esc_url( $embed['url'] ); ?>" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
				<?php
			}//end if
		} else {
			echo '<h3>' . esc_html__( 'access denied', 'academy' ) . '</h3>';
		}//end if
		wp_die();
	}

	public function course_add_to_wishlist() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! is_user_logged_in() ) {
			wp_send_json_error( array( 'redirect_to' => wp_login_url( wp_get_referer() ) ) );
		}

		global $wpdb;
		$course_id          = (int) sanitize_text_field( $_POST['course_id'] );
		$user_id            = get_current_user_id();
		$is_already_in_list = $wpdb->get_row( $wpdb->prepare( "SELECT * from {$wpdb->usermeta} WHERE user_id = %d AND meta_key = 'academy_course_wishlist' AND meta_value = %d;", $user_id, $course_id ) );
		if ( $is_already_in_list ) {
			$wpdb->delete(
				$wpdb->usermeta,
				array(
					'user_id'    => $user_id,
					'meta_key'   => 'academy_course_wishlist',
					'meta_value' => $course_id,
				)
			);
			wp_send_json_success( array( 'is_added' => false ) );
		} else {
			add_user_meta( $user_id, 'academy_course_wishlist', $course_id );
			wp_send_json_success( array( 'is_added' => true ) );
		}
		wp_die();
	}
	public function saved_user_info() {
		check_admin_referer( 'academy_nonce', 'security' );
		$data    = \Academy\Helper::fresh_ajax_request_data( $_POST );
		$data    = \Academy\Helper::sanitize_text_or_array_field( $data );
		$user_id = get_current_user_id();
		foreach ( $data as $key => $value ) {
			update_user_meta( $user_id, $key, $value );
		}
		wp_send_json_success( $data );
		wp_die();
	}
	public function reset_password() {
		check_admin_referer( 'academy_nonce', 'security' );
		$message      = '';
		$data         = \Academy\Helper::fresh_ajax_request_data( $_POST );
		$data         = \Academy\Helper::sanitize_text_or_array_field( $data );
		$current_user = wp_get_current_user();
		if ( $current_user && wp_check_password( $data['current_password'], $current_user->data->user_pass, $current_user->ID ) ) {
			if ( ! empty( $data['new_password'] ) && $data['new_password'] === $data['confirm_new_password'] ) {
				$user = wp_get_current_user();
				// Change password.
				wp_set_password( $data['new_password'], $user->ID );
				// Log-in again.
				wp_set_auth_cookie( $user->ID );
				wp_set_current_user( $user->ID );
				do_action( 'wp_login', $user->user_login, $user );
				wp_send_json_success( esc_html__( 'Successfully, updated your password.', 'academy' ) );
				wp_die();
			} else {
				$message .= esc_html__( 'New Password and Confirm New password do not match equally.', 'academy' );
			}
		} else {
			$message .= esc_html__( 'Current password is incorrect.', 'academy' );
		}
		wp_send_json_error( $message );
		wp_die();
	}
	public function get_user_given_reviews() {
		check_admin_referer( 'academy_nonce', 'security' );
		$user_id = get_current_user_id();
		$reviews = \Academy\Helper::get_reviews_by_user( $user_id );
		$results = [];
		if ( is_array( $reviews ) ) {
			foreach ( $reviews as $review ) {
				$review->post_title     = get_the_title( $review->comment_post_ID );
				$review->post_permalink = esc_url( get_the_permalink( $review->comment_post_ID ) );
				$results[]              = $review;
			}
		}
		wp_send_json_success( $results );
		wp_die();
	}
	public function get_user_received_reviews() {
		check_admin_referer( 'academy_nonce', 'security' );
		$user_id = get_current_user_id();
		$reviews = \Academy\Helper::get_reviews_by_instructor( $user_id );
		$results = [];
		if ( is_array( $reviews ) ) {
			foreach ( $reviews as $review ) {
				$review->post_title     = get_the_title( $review->comment_post_ID );
				$review->post_permalink = esc_url( get_the_permalink( $review->comment_post_ID ) );
				$results[]              = $review;
			}
		}
		wp_send_json_success( $results );
		wp_die();
	}

	public function get_user_purchase_histroy() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! \Academy\Helper::is_active_woocommerce() ) {
			wp_die();
		}
		$user_id = get_current_user_id();
		$orders  = \Academy\Helper::get_orders_by_user_id( $user_id );
		$results = [];
		if ( is_array( $orders ) ) {
			foreach ( $orders as $order ) {
				$courses_order = \Academy\Helper::get_course_enrolled_ids_by_order_id( $order->ID );
				$courses       = [];
				if ( is_array( $courses_order ) ) {
					foreach ( $courses_order as $course ) {
						$courses[] = [
							'ID'        => $course['course_id'],
							'title'     => get_the_title( $course['course_id'] ),
							'permalink' => esc_url( get_the_permalink( $course['course_id'] ) ),
						];
					}
				}
				$wc_order  = wc_get_order( $order->ID );
				$price     = $wc_order->get_total();
				$status    = \Academy\Helper::order_status_context( $order->post_status );
				$results[] = [
					'ID'      => $order->ID,
					'courses' => $courses,
					'price'   => wc_price( $price, array( 'currency' => $wc_order->get_currency() ) ),
					'status'  => $status,
					'date'    => date_i18n( get_option( 'date_format' ), strtotime( $order->post_date ) ),
				];
			}//end foreach
		}//end if
		wp_send_json_success( $results );
		wp_die();
	}

	public function get_user_withdraw_info() {
		check_admin_referer( 'academy_nonce', 'security' );
		$user_id                     = get_current_user_id();
		$results                     = (object) \Academy\Helper::get_earning_by_user_id( $user_id );
		// phpcs:ignore WordPress.NamingConventions.ValidVariableName.UsedPropertyNotSnakeCase
		$results->withdrawMathodType = get_user_meta( $user_id, 'academy_instructor_withdraw_method_type', true );
		// phpcs:ignore WordPress.NamingConventions.ValidVariableName.UsedPropertyNotSnakeCase
		$results->minimumWithdrow    = \Academy\Helper::get_settings( 'instructor_minimum_withdraw_amount', 80 );
		// phpcs:ignore WordPress.NamingConventions.ValidVariableName.UsedPropertyNotSnakeCase
		$results->withdrowHistroy    = \Academy\Helper::get_withdraw_history_by_user_id( $user_id );
		wp_send_json_success( $results );
		wp_die();
	}
	public function get_user_withdraw_settings() {
		check_admin_referer( 'academy_nonce', 'security' );
		$user_id = get_current_user_id();
		$data    = [
			'withdrawMathodType' => get_user_meta( $user_id, 'academy_instructor_withdraw_method_type', true ),
			'paypalEmailAddress' => get_user_meta( $user_id, 'academy_instructor_withdraw_paypal_email', true ),
			'echeckAddress'      => get_user_meta( $user_id, 'academy_instructor_withdraw_echeck_address', true ),
			'bankAccountName'    => get_user_meta( $user_id, 'academy_instructor_withdraw_bank_acocunt_name', true ),
			'bankAccountNumber'  => get_user_meta( $user_id, 'academy_instructor_withdraw_bank_acocunt_number', true ),
			'bankName'           => get_user_meta( $user_id, 'academy_instructor_withdraw_bank_name', true ),
			'bankIBAN'           => get_user_meta( $user_id, 'academy_instructor_withdraw_bank_iban', true ),
			'bankSWIFTCode'      => get_user_meta( $user_id, 'academy_instructor_withdraw_bank_swiftcode', true ),
			'minimum_withdrow'   => \Academy\Helper::get_settings( 'instructor_minimum_withdraw_amount', 80 ),
		];
		wp_send_json_success( $data );
		wp_die();
	}

	public function set_user_withdraw_settings() {
		check_admin_referer( 'academy_nonce', 'security' );
		$data    = \Academy\Helper::fresh_ajax_request_data( $_POST );
		$data    = \Academy\Helper::sanitize_text_or_array_field( $data );
		$user_id = get_current_user_id();
		update_user_meta( $user_id, 'academy_instructor_withdraw_method_type', $data['withdrawMathodType'] );
		update_user_meta( $user_id, 'academy_instructor_withdraw_paypal_email', $data['paypalEmailAddress'] );
		update_user_meta( $user_id, 'academy_instructor_withdraw_echeck_address', $data['echeckAddress'] );
		update_user_meta( $user_id, 'academy_instructor_withdraw_bank_acocunt_name', $data['bankAccountName'] );
		update_user_meta( $user_id, 'academy_instructor_withdraw_bank_acocunt_number', $data['bankAccountNumber'] );
		update_user_meta( $user_id, 'academy_instructor_withdraw_bank_name', $data['bankName'] );
		update_user_meta( $user_id, 'academy_instructor_withdraw_bank_iban', $data['bankIBAN'] );
		update_user_meta( $user_id, 'academy_instructor_withdraw_bank_swiftcode', $data['bankSWIFTCode'] );
		wp_send_json_success( $data );
		wp_die();
	}

	public function withdraw_request_by_user() {
		check_admin_referer( 'academy_nonce', 'security' );

		$user_id = get_current_user_id();
		$data    = \Academy\Helper::fresh_ajax_request_data( $_POST );
		$data    = \Academy\Helper::sanitize_text_or_array_field( $data );

		$withdraw_amount      = (int) $data['withdrawAmount'];
		$withdraw_mathod_type = $data['withdrawMathodType'];
		if ( get_user_meta( $user_id, 'academy_instructor_withdraw_method_type', true ) !== $withdraw_mathod_type ) {
			$message = apply_filters( 'academy/frontend/user_withdraw_wrong_method_type_message', esc_html__( 'Your Request withdraw method type isn\'t match', 'academy' ) );
			wp_send_json_error( array( 'message' => $message ) );
			wp_die();
		}
		$earning      = (object) \Academy\Helper::get_earning_by_user_id( $user_id );
		$min_withdraw = \Academy\Helper::get_settings( 'instructor_minimum_withdraw_amount' );

		if ( $withdraw_amount < $min_withdraw ) {
			$message = apply_filters( 'academy/frontend/user_minimum_withdraw_amount_message', sprintf( '%s %d', esc_html__( 'Minimum withdrawal amount is', 'academy' ), $min_withdraw ) );
			wp_send_json_error( array( 'message' => $message ) );
			wp_die();
		}

		if ( $earning->balance < $withdraw_amount ) {
			$insufficient_balence = apply_filters( 'academy/frontend/user_withdraw_insufficient_balance_message', __( 'Insufficient balance.', 'academy' ) );
			wp_send_json_error( array( 'message' => $insufficient_balence ) );
			wp_die();
		}

		$withdraw_args = apply_filters(
			'academy/frontend/withdraw_data_insert_args',
			array(
				'user_id'     => $user_id,
				'amount'      => $withdraw_amount,
				'method_data' => wp_json_encode( \Academy\Helper::get_user_withdraw_saved_info( $user_id, $withdraw_mathod_type ) ),
				'status'      => 'pending',
				'created_at'  => current_time( 'mysql' ),
			)
		);

		do_action( 'academy/frontend/before_withdraw_data_insert', $withdraw_args );
		$withdraw_id = \Academy\Helper::insert_withdraw( $withdraw_args );
		do_action( 'academy/frontend/after_withdraw_data_insert', $withdraw_id, $withdraw_args );
		wp_send_json_success( $withdraw_args );
		wp_die();
	}

	public function archive_course_filter() {
		check_admin_referer( 'academy_nonce', 'security' );

		$search   = ( isset( $_POST['search'] ) ? sanitize_text_field( $_POST['search'] ) : '' );
		$category = ( isset( $_POST['category'] ) ? \Academy\Helper::sanitize_text_or_array_field( $_POST['category'] ) : [] );
		$tags     = ( isset( $_POST['tags'] ) ? \Academy\Helper::sanitize_text_or_array_field( $_POST['tags'] ) : [] );
		$levels   = ( isset( $_POST['levels'] ) ? \Academy\Helper::sanitize_text_or_array_field( $_POST['levels'] ) : [] );
		$type     = ( isset( $_POST['type'] ) ? \Academy\Helper::sanitize_text_or_array_field( $_POST['type'] ) : [] );
		$orderby  = ( isset( $_POST['orderby'] ) ? sanitize_text_field( $_POST['orderby'] ) : '' );
		$paged    = ( isset( $_POST['paged'] ) ) ? absint( $_POST['paged'] ) : 1;

		$args = \Academy\Helper::prepare_course_search_query_args(
			[
				'search'         => $search,
				'category'       => $category,
				'tags'           => $tags,
				'levels'         => $levels,
				'type'           => $type,
				'paged'          => $paged,
				'orderby'        => $orderby,
				'posts_per_page' => (int) \Academy\Helper::get_customizer_settings( 'course_per_page', 12 ),
			]
		);

		$courses = new \WP_Query( $args );
		ob_start();
		?>
<div class="academy-row">
		<?php
		if ( $courses->have_posts() ) :
			while ( $courses->have_posts() ) :
				$courses->the_post();
				\Academy\Helper::get_template_part( 'content', 'course' );
		endwhile;
			wp_reset_query(); else :
				?>
	<div class='academy-mycourse'>
		<h3 class='academy-not-found'><?php esc_html_e( 'Sorry no course found.', 'academy' ); ?>
		</h3>
	</div>
		<?php endif; ?>
	<div class="academy-courses__pagination academy-col-md-12">
		<?php
		$big = 999999999;
		// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		echo paginate_links(
			array(
				'base'      => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
				'format'    => '?paged=%#%',
				'current'   => max( 1, $paged ),
				'total'     => $courses->max_num_pages,
				'prev_text' => '<i class="academy-icon academy-icon--angle-left"></i>',
				'next_text' => '<i class="academy-icon academy-icon--angle-right"></i>',
			)
		);
		?>
	</div>
</div>
		<?php
		$markup = ob_get_clean();
		wp_send_json_success(
			[
				'markup'      => $markup,
				'found_posts' => $courses->found_posts,
			]
		);
		wp_die();
	}
}
