<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Academy Templates Related all functions write here
 */
// phpcs:ignoreFile
if ( ! function_exists( 'academy_load_canvas_page_template' ) ) {
	function academy_load_canvas_page_template() {
		$templates['academy-canvas.php'] = esc_html__( 'Academy Canvas', 'academy' );
		return $templates;
	}
}

if ( ! function_exists( 'academy_redirect_canvas_page_template' ) ) {
	function academy_redirect_canvas_page_template( $template ) {
		$post = get_post();
		$page_template = get_post_meta( $post->ID, '_wp_page_template', true );
		if ( 'academy-canvas.php' === basename( $page_template ) ) {
			$template = ACADEMY_ROOT_DIR_PATH . 'templates/academy-canvas.php';
		}
		return $template;
	}
}

if ( ! function_exists( 'academy_single_course_sidebar' ) ) {
	function academy_single_course_sidebar() {
		ob_start();
		\Academy\Helper::get_template( 'single-course/sidebar.php' );
		$output = apply_filters( 'academy/single_course_sidebar', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_single_course_header' ) ) {
	function academy_single_course_header() {
		$difficulty_level = get_post_meta( get_the_ID(), 'academy_course_difficulty_level', true );
		$preview_video    = \Academy\Helper::get_course_preview_video( get_the_ID() );
		ob_start();
		\Academy\Helper::get_template(
			'single-course/header.php',
			apply_filters(
				'academy/single_course_header_args',
				[
					'difficulty_level' => $difficulty_level,
					'preview_video'    => $preview_video,
				]
			)
		);
		$output = apply_filters( 'academy/single_course_header', ob_get_clean() );
		echo $output;
	}
}



if ( ! function_exists( 'academy_single_course_description' ) ) {
	function academy_single_course_description() {
		ob_start();
		\Academy\Helper::get_template( 'single-course/description.php' );
		$output = apply_filters( 'academy/single_course_content_description', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_single_course_curriculum' ) ) {
	function academy_single_course_curriculum() {
		$curriculum = get_post_meta( get_the_ID(), 'academy_course_curriculum', true );
		$lessons    = [];
		if ( is_array( $curriculum ) && count( $curriculum ) ) {
			foreach ( $curriculum as $topic ) {
				if ( isset( $topic['topics'] ) && is_array( $topic['topics'] ) && count( $topic['topics'] ) ) {
					foreach ( $topic['topics'] as $lesson ) {
						$featured_media = \Academy\Helper::get_lesson_meta( $lesson['id'], 'featured_media' );
						if ( ! empty( $featured_media ) ) {
							$featured_media = wp_get_attachment_image_src( $featured_media, 'full' );
						}
						$video_duration           = \Academy\Helper::get_lesson_meta( $lesson['id'], 'video_duration' );
						$lessons[ $lesson['id'] ] = array(
							'is_preview_able' => \Academy\Helper::get_lesson_meta( $lesson['id'], 'is_previewable' ),
							'featured_media'  => ( is_array( $featured_media ) ? $featured_media[0] : '' ),
							'video_duration'  => $video_duration,
						);
					}
				}
			}
		}
		ob_start();
		\Academy\Helper::get_template(
			'single-course/curriculum.php',
			array(
				'curriculum' => $curriculum,
				'lessons'    => $lessons,
			)
		);
		$output = apply_filters( 'academy/single_course_content_curriculum', ob_get_clean() );
		echo $output;
	}
}//end if


if ( ! function_exists( 'academy_single_course_instructors' ) ) {
	function academy_single_course_instructors() {
		$instructors = \Academy\Helper::get_instructors_by_course_id( get_the_ID() );
		if ( ! $instructors ) {
			return;
		}
		ob_start();
		\Academy\Helper::get_template(
			'single-course/instructors.php',
			apply_filters(
				'academy/single_course_content_instructors_args',
				[
					'instructors' => $instructors,
				]
			)
		);
		$output = apply_filters( 'academy/single_course_content_instructors', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_single_course_benefits' ) ) {
	function academy_single_course_benefits() {
		$benefits = Academy\Helper::string_to_array( get_post_meta( get_the_ID(), 'academy_course_benefits', true ) );
		ob_start();
		\Academy\Helper::get_template( 'single-course/benefits.php', apply_filters( 'academy/single_course_content_benefits_args', [ 'benefits' => $benefits ] ) );
		$output = apply_filters( 'academy/single_course_content_benefits', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_single_course_additional_info' ) ) {
	function academy_single_course_additional_info() {
		$audience     = Academy\Helper::string_to_array( get_post_meta( get_the_ID(), 'academy_course_audience', true ) );
		$requirements = Academy\Helper::string_to_array( get_post_meta( get_the_ID(), 'academy_course_requirements', true ) );
		$materials    = Academy\Helper::string_to_array( get_post_meta( get_the_ID(), 'academy_course_materials_included', true ) );
		$tabs_nav     = [];
		$tabs_content = [];
		if ( is_array( $audience ) && count( $audience ) > 0 ) {
			$tabs_nav['audience']     = esc_html__( 'Targeted Audience', 'academy' );
			$tabs_content['audience'] = $audience;
		}
		if ( is_array( $requirements ) && count( $requirements ) > 0 ) {
			$tabs_nav['requirements']     = esc_html__( 'Requirements', 'academy' );
			$tabs_content['requirements'] = $requirements;
		}
		if ( is_array( $materials ) && count( $materials ) > 0 ) {
			$tabs_nav['materials']     = esc_html__( 'Materials Included', 'academy' );
			$tabs_content['materials'] = $materials;
		}

		ob_start();
		\Academy\Helper::get_template(
			'single-course/additional-info.php',
			apply_filters(
				'academy/single_course_content_additional_info_args',
				[
					'tabs_nav'     => $tabs_nav,
					'tabs_content' => $tabs_content,
				]
			)
		);
		$output = apply_filters( 'academy/single_course_content_instructors', ob_get_clean() );
		echo $output;
	}
}//end if

if ( ! function_exists( 'academy_single_course_feedback' ) ) {
	function academy_single_course_feedback() {
		$rating = \Academy\Helper::get_course_rating( get_the_ID() );
		ob_start();
		\Academy\Helper::get_template( 'single-course/feedback.php', array( 'rating' => $rating ) );
		$output = apply_filters( 'academy/single_course_content_feedback', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_single_course_reviews' ) ) {
	function academy_single_course_reviews() {
		ob_start();
		if ( comments_open() || get_comments_number() ) {
			comments_template();
		}
		$output = apply_filters( 'academy/single_course_content_reviews', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_archive_course_header' ) ) {
	function academy_archive_course_header() {
		ob_start();
		\Academy\Helper::get_template( 'archive/header.php' );
		$output = apply_filters( 'academy/archive_course_header', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_archive_course_header_filter' ) ) {
	function academy_archive_course_header_filter() {
		global $wp_query;
		$orderby = ( get_query_var( 'orderby' ) ) ? get_query_var( 'orderby' ) : ''; ?>
		<div class="academy-courses__header-filter">
			<p class="academy-courses__header-result-count"><?php esc_html_e( 'Showing all', 'academy' ); ?>
				<span><?php echo $wp_query->found_posts; ?></span> <?php esc_html_e( 'results', 'academy' ); ?>
			</p>
			<form class="academy-courses__header-ordering" method="get">
				<select name="orderby" class="academy-courses__header-orderby" aria-label="Course order"
					onchange="this.form.submit()">
					<option value="" <?php selected( $orderby, '' ); ?>>
						<?php esc_html_e( 'Default Sorting', 'academy' ); ?>
					</option>
					<option value="name" <?php selected( $orderby, 'name' ); ?>>
						<?php esc_html_e( 'Order by course name', 'academy' ); ?>
					</option>
					<option value="date" <?php selected( $orderby, 'date' ); ?>>
						<?php esc_html_e( 'Order by Release Date', 'academy' ); ?>
					</option>
					<option value="modified" <?php selected( $orderby, 'modified' ); ?>>
						<?php esc_html_e( 'Order by Modified Date', 'academy' ); ?>
					</option>
				</select>
				<input type="hidden" name="paged" value="1">
			</form>
		</div>
		<?php
	}
}//end if

if ( ! function_exists( 'academy_no_course_found' ) ) {
	function academy_no_course_found() {
		ob_start();
		\Academy\Helper::get_template( 'archive/course-none.php' );
		$output = apply_filters( 'academy/no_course_found', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_course_pagination' ) ) {
	function academy_course_pagination() {
		ob_start();
		\Academy\Helper::get_template( 'archive/pagination.php' );
		$output = apply_filters( 'academy/archive_course_pagination', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_course_loop_header' ) ) {
	function academy_course_loop_header() {
		global $wpdb;
		$course_id              = get_the_ID();
		$user_id                = get_current_user_id();
		$is_already_in_wishlist = $wpdb->get_row( $wpdb->prepare( "SELECT * from {$wpdb->usermeta} WHERE user_id = %d AND meta_key = 'academy_course_wishlist' AND meta_value = %d;", $user_id, $course_id ) );
		ob_start();
		\Academy\Helper::get_template( 'loop/header.php', array( 'is_already_in_wishlist' => $is_already_in_wishlist ) );
		$output = apply_filters( 'academy/course_loop_header', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_course_loop_content' ) ) {
	function academy_course_loop_content() {
		ob_start();
		\Academy\Helper::get_template( 'loop/content.php' );
		$output = apply_filters( 'academy/course_loop_content', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_course_loop_footer' ) ) {
	function academy_course_loop_footer() {
		ob_start();
		\Academy\Helper::get_template( 'loop/footer.php' );
		$output = apply_filters( 'academy/course_loop_footer', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_course_loop_rating' ) ) {
	function academy_course_loop_rating() {
		$rating = \Academy\Helper::get_course_rating( get_the_ID() );
		ob_start();
		\Academy\Helper::get_template( 'loop/rating.php', [ 'rating' => $rating ] );
		$output = apply_filters( 'academy/course_loop_rating', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_course_loop_enroll' ) ) {
	function academy_course_loop_enroll() {
		ob_start();
		\Academy\Helper::get_template( 'loop/enroll.php' );
		$output = apply_filters( 'academy/course_loop_enroll', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_course_loop_footer_inner_price' ) ) {
	function academy_course_loop_footer_inner_price() {
		$course_id = get_the_ID();
		$is_paid   = \Academy\Helper::is_course_purchasable( $course_id );
		$price     = '';
		if ( \Academy\Helper::is_active_woocommerce() && $is_paid ) {
			$product_id = Academy\Helper::get_course_product_id( $course_id );
			if ( $product_id ) {
				$product = wc_get_product( $product_id );
				if($product){
					$price   = $product->get_price_html();
				}
			}
		}
		ob_start();
		\Academy\Helper::get_template(
			'loop/price.php',
			array(
				'price'   => $price,
				'is_paid' => $is_paid,
			)
		);
		$output = apply_filters( 'academy/course_loop_footer_inner_price', ob_get_clean() );
		echo $output;
	}
}//end if


if ( ! function_exists( 'academy_review_lists' ) ) {
	function academy_review_lists( $comment, $args, $depth ) {
		\Academy\Helper::get_template(
			'single-course/review.php',
			array(
				'comment' => $comment,
				'args'    => $args,
				'depth'   => $depth,
			)
		);
	}
}


if ( ! function_exists( 'academy_review_display_gravatar' ) ) {
	/**
	 * Display the review authors gravatar
	 *
	 * @param array $comment WP_Comment.
	 * @return void
	 */
	function academy_review_display_gravatar( $comment ) {
		echo get_avatar( $comment->comment_author_email, apply_filters( 'academy/review_gravatar_size', '80' ), '' );
	}
}

if ( ! function_exists( 'academy_review_display_rating' ) ) {
	/**
	 * Display the reviewers star rating
	 *
	 * @return void
	 */
	function academy_review_display_rating() {
		if ( post_type_supports( 'academy_courses', 'comments' ) ) {
			\Academy\Helper::get_template( 'single-course/review-rating.php' );
		}
	}
}

if ( ! function_exists( 'academy_review_display_meta' ) ) {
	/**
	 * Display the review authors meta (name, verified owner, review date)
	 *
	 * @return void
	 */
	function academy_review_display_meta() {
		\Academy\Helper::get_template( 'single-course/review-meta.php' );
	}
}


if ( ! function_exists( 'academy_review_display_comment_text' ) ) {

	/**
	 * Display the review content.
	 */
	function academy_review_display_comment_text() {
		echo '<div class="academy-review-description">';
		comment_text();
		echo '</div>';
	}
}


if ( ! function_exists( 'academy_get_rating_html' ) ) {
	/**
	 * Get HTML for ratings.
	 *
	 * @param  float $rating Rating being shown.
	 * @param  int   $count  Total number of ratings.
	 * @return string
	 */
	function academy_get_rating_html( $rating, $count = 0 ) {
		$html = '';
		if ( 0 < $rating ) {
			$html = \Academy\Helper::single_star_rating_generator( $rating );
		}
		return apply_filters( 'academy/course_get_rating_html', $html, $rating, $count );
	}
}

if ( ! function_exists( 'academy_single_course_enroll' ) ) {
	function academy_single_course_enroll() {
		ob_start();
		\Academy\Helper::get_template(
			'single-course/enroll/enroll.php'
		);
		$output = apply_filters( 'academy/single/course_enroll', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_single_course_enroll_content' ) ) {
	function academy_single_course_enroll_content() {
		$course_id   = get_the_ID();
		$user_id     = get_current_user_id();
		$is_enrolled = (bool) \Academy\Helper::is_enrolled( $course_id, $user_id );
		$enrolled    = \Academy\Helper::is_enrolled( get_the_ID(), get_current_user_id() );
		$is_paid     = (bool) \Academy\Helper::is_course_purchasable( $course_id );
		$price       = '';
		if ( \Academy\Helper::is_active_woocommerce() && $is_paid ) {
			$product_id = Academy\Helper::get_course_product_id( $course_id );
			if ( $product_id ) {
				$product = wc_get_product( $product_id );
				if($product){
					$price   = $product->get_price_html();
				}
			}
		}

		$duration       = \Academy\Helper::get_course_duration( $course_id );
		$total_lessons  = \Academy\Helper::get_total_number_of_course_lesson( $course_id );
		$total_enrolled = \Academy\Helper::count_course_enrolled( $course_id );
		$skill          = get_post_meta( $course_id, 'academy_course_difficulty_level', true );
		$language       = get_post_meta( $course_id, 'academy_course_language', true );
		$last_update    = get_the_modified_time( 'F j, Y', $course_id );
		ob_start();
		\Academy\Helper::get_template(
			'single-course/enroll/content.php',
			apply_filters(
				'academy/single/enroll_content_args',
				array(
					'is_enrolled'    => $is_enrolled,
					'enrolled'       => $enrolled,
					'is_paid'        => $is_paid,
					'price'          => $price,
					'duration'       => $duration,
					'total_lessons'  => $total_lessons,
					'total_enrolled' => $total_enrolled,
					'skill'          => $skill,
					'language'       => $language,
					'last_update'    => $last_update,
				)
			)
		);
		$output = apply_filters( 'academy/single/course_enroll_content', ob_get_clean() );
		echo $output;
	}
}//end if

if ( ! function_exists( 'academy_course_enroll_form' ) ) {
	function academy_course_enroll_form() {
		$course_ID = get_the_ID();
		$user_ID   = get_current_user_id();
		$enrolled  = \Academy\Helper::is_enrolled( get_the_ID(), get_current_user_id() );

		$is_administrator = current_user_can( 'administrator' );
		$is_instructor    = \Academy\Helper::is_instructor_of_this_course( $user_ID, $course_ID );
		ob_start();
		if ( $enrolled || $is_administrator || $is_instructor ) {
			\Academy\Helper::get_template( 'single-course/enroll/continue.php' );
		}
		if ( \Academy\Helper::is_course_fully_booked( $course_ID ) ) {
			\Academy\Helper::get_template( 'single-course/enroll/closed-enrollment.php' );
			$output = apply_filters( 'academy/single/course_closed_enrollment', ob_get_clean() );
		} else {
			if ( $enrolled ) {
				$is_completed_course = \Academy\Helper::is_completed_course( $course_ID, $user_ID );
				\Academy\Helper::get_template( 'single-course/enroll/complete-form.php', array( 'is_completed_course' => $is_completed_course ) );
				$output = apply_filters( 'academy/single/course_complete_form', ob_get_clean() );
			} elseif ( \Academy\Helper::is_active_woocommerce() && \Academy\Helper::is_course_purchasable( $course_ID ) ) {
				$product_id = Academy\Helper::get_course_product_id( $course_ID );
				\Academy\Helper::get_template( 'single-course/enroll/add-to-cart-form.php', array( 'product_id' => $product_id ) );
				$output = apply_filters( 'academy/single/course_add_to_cart_form', ob_get_clean() );
			} else {
				\Academy\Helper::get_template( 'single-course/enroll/enroll-form.php' );
				$output = apply_filters( 'academy/single/course_enroll_form', ob_get_clean() );
			}
		}
		echo $output;
	}
}//end if

if ( ! function_exists( 'academy_course_enroll_wishlist_and_share' ) ) {
	function academy_course_enroll_wishlist_and_share() {
		global $wpdb;
		$course_id              = get_the_ID();
		$user_id                = get_current_user_id();
		$is_already_in_wishlist = $wpdb->get_row( $wpdb->prepare( "SELECT * from {$wpdb->usermeta} WHERE user_id = %d AND meta_key = 'academy_course_wishlist' AND meta_value = %d;", $user_id, $course_id ) );
		ob_start();
		\Academy\Helper::get_template(
			'single-course/enroll/wishlist-and-share.php',
			apply_filters(
				'academy/single/course_enroll_wishlist_and_share_args',
				[
					'is_already_in_wishlist' => $is_already_in_wishlist,
				]
			)
		);
		$output = apply_filters( 'academy/single/course_enroll_wishlist_and_share', ob_get_clean() );
		echo $output;
	}
}


if ( ! function_exists( 'academy_archive_course_filter_widget' ) ) {
	function academy_archive_course_filter_widget() {
		$filters = \Academy\Helper::get_customizer_settings(
			'archive_course_filters',
			array(
				'items' =>
							array(
								'search'   => 1,
								'category' => 1,
								'tags'     => 1,
								'levels'   => 1,
								'type'     => 1,
							),
			)
		);

		$filters = apply_filters( 'academy/archive/course_filter_widget_args', $filters['items'] );

		ob_start();

		foreach ( $filters as $key => $value ) {
			$filter_function = 'academy_archive_course_filter_by_' . $key;
			if ( $value && function_exists( $filter_function ) ) {
				$filter_function();
			}
		}
		$output = apply_filters( 'academy/archive/widgets/course_filter_widget', ob_get_clean() );
		echo $output;
	}
}//end if



if ( ! function_exists( 'academy_archive_course_filter_by_search' ) ) {
	function academy_archive_course_filter_by_search() {
		ob_start();
		\Academy\Helper::get_template( 'archive/widgets/search.php', apply_filters( 'academy/archive/course_filter_by_search_args', [] ) );
		$output = apply_filters( 'academy/archive/widgets/course_filter_by_search', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_archive_course_filter_by_category' ) ) {
	function academy_archive_course_filter_by_category() {
		$categories = Academy\Helper::get_all_courses_category_lists();
		ob_start();
		\Academy\Helper::get_template(
			'archive/widgets/category.php',
			apply_filters(
				'academy/archive/course_filter_by_category_args',
				[
					'categories' => $categories,
				]
			)
		);
		$output = apply_filters( 'academy/archive/widgets/course_filter_by_category', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_archive_course_filter_by_tags' ) ) {
	function academy_archive_course_filter_by_tags() {
		$tags = get_terms(
			array(
				'taxonomy'   => 'academy_courses_tag',
				'hide_empty' => true,
			)
		);

		ob_start();
		\Academy\Helper::get_template(
			'archive/widgets/tags.php',
			apply_filters(
				'academy/archive/course_filter_by_tags_args',
				[
					'tags' => $tags,
				]
			)
		);
		$output = apply_filters( 'academy/archive/course_filter_by_tags', ob_get_clean() );
		echo $output;
	}
}//end if

if ( ! function_exists( 'academy_archive_course_filter_by_levels' ) ) {
	function academy_archive_course_filter_by_levels() {
		$levels = array(
			'beginner'     => __( 'Beginner', 'academy' ),
			'intermediate' => __( 'Intermediate', 'academy' ),
			'experts'      => __( 'Expert', 'academy' ),
		);

		ob_start();
		\Academy\Helper::get_template(
			'archive/widgets/levels.php',
			apply_filters(
				'academy/archive/course_filter_by_levels_args',
				[
					'levels' => $levels,
				]
			)
		);
		$output = apply_filters( 'academy/archive/course_filter_by_levels_args', ob_get_clean() );
		echo $output;
	}
}//end if

if ( ! function_exists( 'academy_archive_course_filter_by_type' ) ) {
	function academy_archive_course_filter_by_type() {
		$type = array(
			'free' => __( 'Free', 'academy' ),
			'paid' => __( 'Paid', 'academy' ),
		);
		ob_start();
		\Academy\Helper::get_template(
			'archive/widgets/type.php',
			apply_filters(
				'academy/archive/course_filter_by_type_args',
				[
					'type' => $type,
				]
			)
		);
		$output = apply_filters( 'academy/archive/course_filter_by_type', ob_get_clean() );
		echo $output;
	}
}


if ( ! function_exists( 'academy_archive_course_sidebar' ) ) {
	function academy_archive_course_sidebar() {
		ob_start();
		\Academy\Helper::get_template( 'archive/sidebar.php' );
		$output = apply_filters( 'academy/archive/course_sidebar', ob_get_clean() );
		echo $output;
	}
}


if ( ! function_exists( 'academy_instructor_public_profile_sidebar' ) ) {
	function academy_instructor_public_profile_sidebar() {
		$author_ID    = Academy\Helper::get_the_author_id();
		$reviews      = \Academy\Helper::get_instructor_ratings( $author_ID );
		$website_url  = get_user_meta( $author_ID, 'academy_website_url', true );
		$facebook_url = get_user_meta( $author_ID, 'academy_facebook_url', true );
		$github_url   = get_user_meta( $author_ID, 'academy_github_url', true );
		$twitter_url  = get_user_meta( $author_ID, 'academy_twitter_url', true );
		$linkdin_url  = get_user_meta( $author_ID, 'academy_linkedin_url', true );
		ob_start();
		\Academy\Helper::get_template(
			'instructor/sidebar.php',
			apply_filters(
				'academy/instructor/instructor_public_profile_sidebar_args',
				[
					'author_ID'    => $author_ID,
					'reviews'      => $reviews,
					'website_url'  => $website_url,
					'facebook_url' => $facebook_url,
					'github_url'   => $github_url,
					'twitter_url'  => $twitter_url,
					'linkdin_url'  => $linkdin_url,
				]
			)
		);
		$output = apply_filters( 'academy/single/instructor_public_profile_sidebar', ob_get_clean() );
		echo $output;
	}
}//end if

if ( ! function_exists( 'academy_global_courses' ) ) {
	function academy_global_courses() {
		ob_start();
		\Academy\Helper::get_template( 'global/courses.php' );
		$output = apply_filters( 'academy/global/courses', ob_get_clean() );
		echo $output;
	}
}

if ( ! function_exists( 'academy_instructor_public_profile_header' ) ) {
	function academy_instructor_public_profile_header() {
		$author_ID       = Academy\Helper::get_the_author_id();
		$cover_photo_url = get_the_author_meta( 'academy_cover_photo', $author_ID );
		if(empty($cover_photo_url)){
			$cover_photo_url = apply_filters('academy/instructor/public_profile_placeholder_cover_photo_url', ACADEMY_ASSETS_URI . 'images/banner.jpg');
		}
		$share_config    = array(
			'title' => Academy\Helper::get_the_author_name( $author_ID ),
			'text'  => get_the_author_meta( 'academy_profile_designation', $author_ID ),
			'image' => esc_url( Academy\Helper::get_the_author_thumbnail_url( $author_ID ) ),
		);
		ob_start();
		\Academy\Helper::get_template(
			'instructor/header.php',
			apply_filters(
				'academy/instructor/public_profile_header_args',
				[
					'cover_photo_url' => $cover_photo_url,
					'share_config'    => $share_config,
				]
			)
		);
		$output = apply_filters( 'academy/instructor/profile_header', ob_get_clean() );
		echo $output;
	}
}//end if

if ( ! function_exists( 'academy_instructor_public_profile_tabs_nav' ) ) {
	function academy_instructor_public_profile_tabs_nav() {
		ob_start();
		\Academy\Helper::get_template(
			'instructor/tab-navbar.php',
			apply_filters(
				'academy/instructor/public_profile_tabs_nav_args',
				[]
			)
		);
		$output = apply_filters( 'academy/instructor/public_profile_tabs_nav', ob_get_clean() );
		echo $output;
	}
}
if ( ! function_exists( 'academy_instructor_public_profile_tabs_content' ) ) {
	function academy_instructor_public_profile_tabs_content() {
		ob_start();
		\Academy\Helper::get_template(
			'instructor/tab-content.php',
			apply_filters(
				'academy/instructor/public_profile_tabs_content_args',
				[]
			)
		);
		$output = apply_filters( 'academy/instructor/public_profile_tabs_content', ob_get_clean() );
		echo $output;
	}
}


if ( ! function_exists( 'academy_instructor_public_profile_reviews' ) ) {
	function academy_instructor_public_profile_reviews() {
		$author_ID = get_query_var( 'author' );
		$reviews   = \Academy\Helper::get_reviews_by_instructor( $author_ID );
		$results   = [];
		if ( is_array( $reviews ) ) {
			foreach ( $reviews as $review ) {
				$review->post_title     = get_the_title( $review->comment_post_ID );
				$review->post_permalink = esc_url( get_the_permalink( $review->comment_post_ID ) );
				$results[]              = $review;
			}
		}
		ob_start();
		\Academy\Helper::get_template(
			'instructor/reviews.php',
			apply_filters(
				'academy/instructor/public_profile_reviews_args',
				[ 'reviews' => $results ]
			)
		);
		$output = apply_filters( 'academy/instructor/public_profile_reviews', ob_get_clean() );
		echo $output;
	}
}//end if

if(!function_exists('academy_update_avatar_url')){
	function academy_update_avatar_url($url, $user){
		if(is_object($user)){
			$profile_photo = get_user_meta($user->ID, 'academy_profile_photo', true);
			if(!empty($profile_photo)){
				return esc_url($profile_photo);
			}
		}
		return $url;
	}
}

if(!function_exists('academy_update_avatar_data')){
	function academy_update_avatar_data($args, $user_id){
		if($user_id){
			$profile_photo = get_user_meta($user_id, 'academy_profile_photo', true);
			if(!empty($profile_photo)){
				$args['url'] = esc_url($profile_photo);
				return $args;
			}
		}
		return $args;
	}
}
