<?php
namespace Academy;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Helper {

	use Traits\Courses;
	use Traits\Lessons;
	use Traits\Instructor;
	use Traits\Earning;
	use Traits\Withdrawals;

	public static function get_time() {
		return time() + ( get_option( 'gmt_offset' ) * HOUR_IN_SECONDS );
	}

	/**
	 * List of admin menu
	 */
	public static function get_admin_menu_list() {
		$menu                         = [];
		$is_manage_options            = current_user_can( 'manage_options' );
		$is_manage_academy_instructor = current_user_can( 'manage_academy_instructor' );
		if ( $is_manage_options ) {
			$menu[ ACADEMY_PLUGIN_SLUG ] = [
				'title'      => __( 'Analytics', 'academy' ),
				'capability' => 'manage_options',
			];
		}

		if ( $is_manage_academy_instructor ) {
			$menu[ ACADEMY_PLUGIN_SLUG . '-courses' ]         = [
				'title'      => __( 'All Courses', 'academy' ),
				'capability' => 'manage_academy_instructor',
			];
			$menu[ ACADEMY_PLUGIN_SLUG . '-course' ]          = [
				'title'      => __( 'Add New Course', 'academy' ),
				'capability' => 'manage_academy_instructor',
			];
			$menu[ ACADEMY_PLUGIN_SLUG . '-category' ]         = [
				'title'      => __( 'Category', 'academy' ),
				'capability' => 'manage_academy_instructor',
			];
			$menu[ ACADEMY_PLUGIN_SLUG . '-tag' ]         = [
				'title'      => __( 'Tags', 'academy' ),
				'capability' => 'manage_academy_instructor',
			];
			$menu[ ACADEMY_PLUGIN_SLUG . '-lessons' ]         = [
				'title'      => __( 'All Lessons', 'academy' ),
				'capability' => 'manage_academy_instructor',
			];
			$menu[ ACADEMY_PLUGIN_SLUG . '-lesson' ]          = [
				'title'      => __( 'Add New Lesson', 'academy' ),
				'capability' => 'manage_academy_instructor',
			];
			$menu[ ACADEMY_PLUGIN_SLUG . '-question_answer' ] = [
				'title'      => __( 'Question & Answer', 'academy' ),
				'capability' => 'manage_academy_instructor',
			];
		}//end if
		if ( $is_manage_options ) {
			$menu[ ACADEMY_PLUGIN_SLUG . '-withdraw' ]    = [
				'title'      => __( 'Withdraw Requests', 'academy' ),
				'capability' => 'manage_options',
			];
			$menu[ ACADEMY_PLUGIN_SLUG . '-instructors' ] = [
				'title'      => __( 'Instructors', 'academy' ),
				'capability' => 'manage_options',
			];
			$menu[ ACADEMY_PLUGIN_SLUG . '-students' ]    = [
				'title'      => __( 'Students', 'academy' ),
				'capability' => 'manage_options',
			];
			$menu[ ACADEMY_PLUGIN_SLUG . '-settings' ]    = [
				'title'      => __( 'Settings', 'academy' ),
				'capability' => 'manage_options',
			];
		}
		return apply_filters( 'academy/admin_menu_list', $menu );
	}
	/**
	 * Check Supported Post type for admin page and plugin main settings page
	 *
	 * @param string $hook
	 * @return bool
	 */
	public static function plugin_page_hook_suffix( $hook ) {
		if ( 'toplevel_page_' . ACADEMY_PLUGIN_SLUG === $hook || 'profile.php' === $hook ) {
			return true;
		} else {
			foreach ( self::get_admin_menu_list() as $item_key => $item_value ) {
				if ( ACADEMY_PLUGIN_SLUG . '-lms_page_' . $item_key === $hook ) {
					return true;
				}
			}
		}
		return false;
	}
	public static function is_dev_mode_enable() {
		$whitelist = array( '127.0.0.1', '::1' );
		if ( in_array( $_SERVER['REMOTE_ADDR'], $whitelist, true ) ) {
			return true;
		}
		return false;
	}

	public static function get_settings_assets_data() {
		$settings = new \Academy\Admin\Settings();
		$settings->build_settings();
		return $settings->settings;
	}

	public static function get_settings( $key, $default = null ) {
		global $academy_settings;
		if ( isset( $academy_settings->{$key} ) ) {
			return $academy_settings->{$key};
		}
		return $default;
	}

	public static function get_customizer_settings( $key, $default = null ) {
		$customizer_settings = get_option( 'academy_customizer_settings' );
		if ( isset( $customizer_settings[ $key ] ) ) {
			return $customizer_settings[ $key ];
		}
		return $default;
	}

	public static function get_customizer_style_settings( $key, $default = null ) {
		$customizer_settings = get_option( 'academy_customizer_style_settings' );
		if ( isset( $customizer_settings[ $key ] ) ) {
			return $customizer_settings[ $key ];
		}
		return $default;
	}

	public static function get_column_size( $number_of_column ) {
		return ceil( 12 / $number_of_column );
	}

	public static function get_responsive_column( $columns ) {
		if ( is_array( $columns ) ) {
			$device = array(
				'desktop' => 'lg',
				'tablet' => 'md',
				'mobile' => 'sm',
			);
			$classes = '';
			foreach ( $columns as $mode => $column ) {
				if ( $column ) {
					$classes .= ' academy-col-' . $device[ $mode ] . '-' . ceil( 12 / $column );
				}
			}
			return ltrim( $classes );
		}
		return '';
	}

	/**
	 * Get the template path.
	 *
	 * @return string
	 */
	public static function template_path() {
		return apply_filters( 'academy\template_path', 'academy/' );
	}
	/**
	 * Get the template path.
	 *
	 * @return string
	 */
	public static function plugin_path() {
		return apply_filters( 'academy\plugin_path', ACADEMY_ROOT_DIR_PATH );
	}

	/**
	 * Get template part (for templates like the course-loop).
	 *
	 * ACADEMY_TEMPLATE_DEBUG_MODE will prevent overrides in themes from taking priority.
	 *
	 * @param mixed  $slug Template slug.
	 * @param string $name Template name (default: '').
	 */
	public static function get_template_part( $slug, $name = '' ) {
		$template = false;
		if ( $name ) {
			$template = ACADEMY_TEMPLATE_DEBUG_MODE ? '' : locate_template(
				array(
					"{$slug}-{$name}.php",
					self::template_path() . "{$slug}-{$name}.php",
				)
			);

			if ( ! $template ) {
				$fallback = self::plugin_path() . "/templates/{$slug}-{$name}.php";
				$template = file_exists( $fallback ) ? $fallback : '';
			}
		}

		if ( ! $template ) {
			// If template file doesn't exist, look in yourtheme/slug.php and yourtheme/academy/slug.php.
			$template = ACADEMY_TEMPLATE_DEBUG_MODE ? '' : locate_template(
				array(
					"{$slug}.php",
					self::template_path() . "{$slug}.php",
				)
			);
		}
		// Allow 3rd party plugins to filter template file from their plugin.
		$template = apply_filters( 'academy/get_template_part', $template, $slug, $name );
		if ( $template ) {
			load_template( $template, false );
		}
	}

	/**
	 * Locate a template and return the path for inclusion.
	 *
	 * This is the load order:
	 *
	 * yourtheme/$template_path/$template_name
	 * yourtheme/$template_name
	 * $default_path/$template_name
	 *
	 * @param string $template_name Template name.
	 * @param string $template_path Template path. (default: '').
	 * @param string $default_path  Default path. (default: '').
	 * @return string
	 */
	public static function locate_template( $template_name, $template_path = '', $default_path = '' ) {
		if ( ! $template_path ) {
			$template_path = self::template_path();
		}

		if ( ! $default_path ) {
			$default_path = self::plugin_path() . 'templates/';
		}

		// Look within passed path within the theme - this is priority.
		if ( false !== strpos( $template_name, 'academy_courses__category' ) || false !== strpos( $template_name, 'academy_courses_tag' ) ) {
			$cs_template = str_replace( '_', '-', $template_name );
			$template    = locate_template(
				array(
					trailingslashit( $template_path ) . $cs_template,
					$cs_template,
				)
			);
		}

		if ( empty( $template ) ) {
			$template = locate_template(
				array(
					trailingslashit( $template_path ) . $template_name,
					$template_name,
				)
			);
		}

		// Get default template/.
		if ( ! $template || ACADEMY_TEMPLATE_DEBUG_MODE ) {
			if ( empty( $cs_template ) ) {
				$template = $default_path . $template_name;
			} else {
				$template = $default_path . $cs_template;
			}
		}

		// Return what we found.
		return apply_filters( 'academy/locate_template', $template, $template_name, $template_path );
	}

	/**
	 * Get other templates (e.g. course attributes) passing attributes and including the file.
	 *
	 * @param string $template_name Template name.
	 * @param array  $args          Arguments. (default: array).
	 * @param string $template_path Template path. (default: '').
	 * @param string $default_path  Default path. (default: '').
	 */
	public static function get_template( $template_name, $args = array(), $template_path = '', $default_path = '' ) {
		$template = false;

		if ( ! $template ) {
			$template = self::locate_template( $template_name, $template_path, $default_path );
		}

		// Allow 3rd party plugin filter template file from their plugin.
		$filter_template = apply_filters( 'academy/get_template', $template, $template_name, $args, $template_path, $default_path );

		if ( $filter_template !== $template ) {
			if ( ! file_exists( $filter_template ) ) {
				/* translators: %s template */
				wc_doing_it_wrong( __FUNCTION__, sprintf( __( '%s does not exist.', 'academy' ), '<code>' . $filter_template . '</code>' ), '1.0.0' );
				return;
			}
			$template = $filter_template;
		}

		$action_args = array(
			'template_name' => $template_name,
			'template_path' => $template_path,
			'located'       => $template,
			'args'          => $args,
		);

		if ( ! empty( $args ) && is_array( $args ) ) {
			if ( isset( $args['action_args'] ) ) {
				wc_doing_it_wrong(
					__FUNCTION__,
					__( 'action_args should not be overwritten when calling academy/get_template.', 'academy' ),
					'1.0.0'
				);
				unset( $args['action_args'] );
			}
            extract($args); // @codingStandardsIgnoreLine
		}

		do_action( 'academy/before_template_part', $action_args['template_name'], $action_args['template_path'], $action_args['located'], $action_args['args'] );
		include $action_args['located'];

		do_action( 'academy/after_template_part', $action_args['template_name'], $action_args['template_path'], $action_args['located'], $action_args['args'] );
	}

	/**
	 * Academy Date Format - Allows to change date format for everything Academy.
	 *
	 * @return string
	 */
	public static function get_date_format() {
		$date_format = get_option( 'date_format' );
		if ( empty( $date_format ) ) {
			// Return default date format if the option is empty.
			$date_format = 'F j, Y';
		}
		return apply_filters( 'academy/date_format', $date_format );
	}

	public static function string_to_array( $string ) {
		if ( empty( $string ) ) {
			return [];
		}
		$string = explode( "\n", $string );
		return array_filter( array_map( 'trim', $string ) );
	}

	public static function count_posts_by_user( $post_author = null, $post_type = array(), $post_status = array() ) {
		global $wpdb;

		if ( empty( $post_author ) ) {
			return 0;
		}

		$post_status = (array) $post_status;
		$post_type   = (array) $post_type;

		$sql = $wpdb->prepare( "SELECT COUNT(*) FROM $wpdb->posts WHERE post_author = %d AND ", $post_author );

		// Post status
		if ( ! empty( $post_status ) ) {
			$argtype = array_fill( 0, count( $post_status ), '%s' );
			$where   = '(post_status=' . implode( ' OR post_status=', $argtype ) . ') AND ';
			// phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared
			$sql    .= $wpdb->prepare( $where, $post_status );
		}

		// Post type
		if ( ! empty( $post_type ) ) {
			$argtype = array_fill( 0, count( $post_type ), '%s' );
			$where   = '(post_type=' . implode( ' OR post_type=', $argtype ) . ') AND ';
			// phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared
			$sql    .= $wpdb->prepare( $where, $post_type );
		}

		$sql  .= '1=1';
		// phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared
		$count = $wpdb->get_var( $sql );
		return $count;
	}
	public static function calculate_percentage( $total_count, $completed_count ) {
		if ( $total_count > 0 && $completed_count > 0 ) {
			return number_format( ( $completed_count * 100 ) / $total_count );
		}
		return 0;
	}

	public static function youtube_id_from_url( $url ) {
		$parts = wp_parse_url( $url );
		if ( isset( $parts['query'] ) ) {
			parse_str( $parts['query'], $qs );
			if ( isset( $qs['v'] ) ) {
				return $qs['v'];
			} elseif ( isset( $qs['vi'] ) ) {
				return $qs['vi'];
			}
		}
		if ( isset( $parts['path'] ) ) {
			$path = explode( '/', trim( $parts['path'], '/' ) );
			return $path[ count( $path ) - 1 ];
		}
		return false;
	}

	public static function parse_embedded_url( $string ) {
		preg_match( '/src="(.*?(?="))"/', $string, $src );
		preg_match( '/allow="(.*?(?="))"/', $string, $allow );
		return array(
			'url'   => ( isset( $src[1] ) ? $src[1] : '' ),
			'allow' => ( isset( $allow[1] ) ? $allow[1] : '' ),
		);
	}

	public static function vimeo_id_from_url( $url ) {
		if ( preg_match( '/(https?:\/\/)?(www\.)?(player\.)?vimeo\.com\/([a-z]*\/)*([0-9]{6,11})[?]?.*/', $url, $output_array ) ) {
			return $output_array[5];
		}
	}

	public static function generate_video_embed_url( $url ) {
		if ( strpos( $url, 'youtube' ) > 0 || strpos( $url, 'youtu.be' ) > 0 ) {
			return 'https://www.youtube.com/embed/' . self::youtube_id_from_url( $url );
		} elseif ( strpos( $url, 'vimeo' ) > 0 ) {
			return 'https://player.vimeo.com/video/' . self::vimeo_id_from_url( $url ) . '?title=0&byline=0';
		}
		return $url;
	}

	public static function is_active_woocommerce() {
		include_once ABSPATH . 'wp-admin/includes/plugin.php';
		return is_plugin_active( 'woocommerce/woocommerce.php' );
	}

	public static function sanitize_text_or_array_field( $array_or_string ) {
		$boolean = [ 'true', 'false', '1', '0' ];
		if ( is_string( $array_or_string ) ) {
			$array_or_string = in_array( $array_or_string, $boolean, true ) || is_bool( $array_or_string ) ? rest_sanitize_boolean( $array_or_string ) : sanitize_text_field( $array_or_string );
		} elseif ( is_array( $array_or_string ) ) {
			foreach ( $array_or_string as $key => &$value ) {
				if ( is_array( $value ) ) {
					$value = self::sanitize_text_or_array_field( $value );
				} else {
					$value = in_array( $value, $boolean, true ) || is_bool( $value ) ? rest_sanitize_boolean( $value ) : sanitize_text_field( $value );
				}
			}
		}
		return $array_or_string;
	}
	public static function fresh_ajax_request_data( $data ) {
		$remove = [ 'action', 'security' ];
		return array_diff_key( $data, array_flip( $remove ) );
	}

	public static function get_all_students() {
		global $wpdb;
		$results = $wpdb->get_results(
			$wpdb->prepare(
				"SELECT *
			FROM 	{$wpdb->users} 
					INNER JOIN {$wpdb->usermeta} 
							ON ( {$wpdb->users}.ID = {$wpdb->usermeta}.user_id )
			WHERE 	{$wpdb->usermeta}.meta_key = %s;",
				'is_academy_student',
			)
		);
		return $results;
	}
	public static function prepare_get_all_students_response( $students ) {
		if ( ! is_array( $students ) ) {
			return;
		}

		$results = [];
		foreach ( $students as $student ) {
			$courses_ids = self::get_completed_courses_ids_by_user( $student->ID );
			if ( is_array( $courses_ids ) && count( $courses_ids ) > 0 ) {
				$completed_courses = [];
				foreach ( $courses_ids as $courses_id ) {
					$completed_courses[] = [
						'title'     => get_the_title( $courses_id ),
						'permalink' => get_the_permalink( $courses_id ),
					];
				}
				$student->completed_courses = $completed_courses;
			}
			$results[] = $student;
		}
		return $results;
	}
	public static function get_the_course_thumbnail_url( $size = 'post-thumbnail' ) {
		$post_id           = get_the_ID();
		$post_thumbnail_id = (int) get_post_thumbnail_id( $post_id );
		if ( $post_thumbnail_id ) {
			$size = apply_filters( 'academy/course_thumbnail_size', $size, $post_id );
			return wp_get_attachment_image_url( $post_thumbnail_id, $size );
		}
		return ACADEMY_ASSETS_URI . '/images/thumbnail-placeholder.png';
	}


	public static function get_current_term_id() {
		$queried         = get_queried_object();
		$current_term_id = ( is_object( $queried ) && property_exists( $queried, 'term_id' ) ) ? $queried->term_id : false;
		return $current_term_id;
	}

	public static function prepare_courses_category_results( $terms, $parent_id = 0 ) {
		$category = array();
		foreach ( $terms as $term ) {
			if ( $term->parent === $parent_id ) {
				$term->children = self::prepare_courses_category_results( $terms, $term->term_id );
				$category[]     = $term;
			}
		}
		return $category;
	}

	public static function get_all_courses_category_lists() {
		$categories = get_terms(
			array(
				'taxonomy'   => 'academy_courses_category',
				'hide_empty' => true,
			)
		);
		return self::prepare_courses_category_results( $categories );
	}

	public static function get_page_permalink( $page, $fallback = null ) {
		$page_id   = self::get_settings( $page );
		$permalink = 0 < $page_id ? get_permalink( $page_id ) : '';
		if ( ! $permalink ) {
			$permalink = is_null( $fallback ) ? get_home_url() : $fallback;
		}
		return apply_filters( 'academy/get_' . $page . '_permalink', $permalink );
	}

	public static function oembed_get( $url, $args = '' ) {
		$oembed = _wp_oembed_get_object();
		return $oembed->get_data( $url, $args );
	}

	public static function get_basic_url_to_embed_url( $url ) {
		$embedObject = self::oembed_get( $url );
		if ( $embedObject ) {
			return self::parse_embedded_url( $embedObject->html );
		}
		return array(
			'url'   => self::generate_video_embed_url( $url ),
			'allow' => '',
		);
	}
	public static function minify_css( $css ) {
		$css = preg_replace( '/\/\*((?!\*\/).)*\*\//', '', $css );
		$css = preg_replace( '/\s{2,}/', ' ', $css );
		$css = preg_replace( '/\s*([:;{}])\s*/', '$1', $css );
		$css = preg_replace( '/;}/', '}', $css );
		return $css;
	}
}
