<?php
namespace Academy;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Academy\Admin\Settings;

class Installer {

	public $academy_version;
	public static function init() {
		$self = new self();
		$self->academy_version = get_option( 'academy_version' );
		$self->save_main_settings();
		Database::create_initial_custom_table();
		$self->add_role();
		$self->create_initial_course();
		$self->create_initial_pages();
		$self->save_option();
	}
	public function save_main_settings() {
		$settings = new Settings();
		$settings->save_settings();
	}
	public function save_option() {
		if ( ! $this->academy_version ) {
			add_option( 'academy_version', ACADEMY_VERSION );
		}
		if ( ! get_option( 'academy_db_version' ) ) {
			add_option( 'academy_db_version', ACADEMY_DB_VERSION );
		}
		if ( ! get_option( 'academy_first_install_time' ) ) {
			add_option( 'academy_first_install_time', Helper::get_time() );
		}
		update_option( 'academy_required_rewrite_flush', Helper::get_time() );
	}
	public function add_role() {
		// student role
		Classes\Role::add_student_role();
		// instructor role
		Classes\Role::add_instructor_role();
	}
	public function create_initial_course() {
		global $wpdb;
		if ( $this->academy_version ) {
			return;
		}
		$post_id = wp_insert_post([
			'post_title'    => esc_html__( 'Hello Academy LMS!', 'academy' ),
			'post_content'  => esc_html__( 'Welcome to Academy LMS. This is your first course. Edit or delete it, then start creating new course!', 'academy' ),
			'post_status'   => 'publish',
			'post_type'     => 'academy_courses',
		]);
		if ( $post_id ) {
			$user_id = get_current_user_id();
			$attached = (int) $wpdb->get_var(
				$wpdb->prepare(
					"SELECT COUNT(umeta_id) FROM {$wpdb->usermeta} 
					WHERE user_id = %d AND meta_key = %s AND meta_value = %d ",
					$user_id,
					'academy_instructor_course_id',
					$post_id
				)
			);
			if ( ! $attached ) {
				add_user_meta( $user_id, 'academy_instructor_course_id', $post_id );
			}
		}
	}
	public function create_initial_pages() {
		if ( $this->academy_version ) {
			return;
		}
		$settings = json_decode( get_option( ACADEMY_SETTINGS_NAME, '{}' ), true );
		$page_lists = [
			'frontend_dashboard_page' => [
				'post_title'    => esc_html__( 'Dashboard', 'academy' ),
				'post_status'   => 'publish',
				'post_type' => 'page',
			],
			'course_page' => [
				'post_title'    => esc_html__( 'Courses', 'academy' ),
				'post_status'   => 'publish',
				'post_type' => 'page',
			],
			'frontend_student_reg_page' => [
				'post_title'    => esc_html__( 'Student Registration', 'academy' ),
				'post_status'   => 'publish',
				'post_type' => 'page',
			],
			'frontend_instructor_reg_page' => [
				'post_title'    => esc_html__( 'Instructor Registration', 'academy' ),
				'post_status'   => 'publish',
				'post_type' => 'page',
			],
		];

		foreach ( $page_lists as $key => $page ) {
			if ( null === get_page_by_title( $page['post_title'] ) ) {
				$post_id = (string) wp_insert_post( $page );
				if ( $post_id && empty( $settings[ $key ] ) ) {
					$settings[ $key ] = $post_id;
					// set page template
					update_post_meta( $post_id, '_wp_page_template', 'academy-canvas.php' );
				}
			}
		}
		update_option( ACADEMY_SETTINGS_NAME, wp_json_encode( $settings ), false );
	}
}
