<?php
namespace  Academy;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Miscellaneous {
	public static function init() {
		$self = new self();
		add_action( 'init', array( $self, 'add_image_sizes' ) );
		add_action( 'admin_bar_menu', array( $self, 'add_admin_bar_menu' ), 90 );
		add_action( 'rest_delete_academy_courses', array( $self, 'delete_associated_enrollment' ) );
	}

	public function add_image_sizes() {
		add_image_size( 'academy_thumbnail', 1280, 855, true );
	}

	public function add_admin_bar_menu( $wp_admin_bar ) {
		$dashboard_page_id = (int) \Academy\Helper::get_settings( 'frontend_dashboard_page' );
		$title = (current_user_can('manage_academy_instructor') ? esc_html__( 'Instructor Dashboard', 'academy' ) : esc_html__( 'Student Dashboard', 'academy' ));
		$wp_admin_bar->add_node(
			array(
				'id'     => 'academyfrontenddashboard',
				'title'  => $title,
				'href'   => get_the_permalink( $dashboard_page_id ),
				'parent' => 'site-name',
			)
		);

		if ( is_singular( 'academy_courses' ) && current_user_can( 'edit_posts' ) ) {
			$wp_admin_bar->add_menu(
				array(
					'id'    => 'academycourses',
					'title' => esc_html__( 'Edit Course', 'academy' ),
					'href'  => esc_url( admin_url( 'admin.php?page=academy-course&id=' . get_the_ID() . '&action=edit' ) ),
				)
			);
		}
	}

	public function delete_associated_enrollment ($post){
		$course_id = $post->ID;
		$user_id   = $post->post_author;
		// delete single instructor
		delete_user_meta( $user_id, 'academy_instructor_course_id', $course_id );
		// delete multi instructor data
		$instructors = \Academy\Helper::get_instructors_by_course_id( $course_id );
		if(is_array($instructors)){
			foreach($instructors as $instructor){
				delete_user_meta( $instructor->ID, 'academy_instructor_course_id', $course_id );
			}
		}
		// delete enrolled data
		\Academy\Helper::cancel_course_enroll( $course_id, $user_id);
	}
}
